@@ -107,10 +107,10 @@ int AutoToolsAction::plug( TQWidget* w, int index )
 	if (kapp && !kapp->authorizeTDEAction(name()))
 		return -1;
 	
-	if ( ::tqqt_cast<TQToolButton*>( w ) )
+	if ( ::tqt_cast<TQToolButton*>( w ) )
 	{
 		TQToolButton* tb = static_cast<TQToolButton*>( w );
-		connect( tb, TQT_SIGNAL( clicked() ), this, TQT_SLOT( activate() ) );
+		connect( tb, TQ_SIGNAL( clicked() ), this, TQ_SLOT( activate() ) );
 		int id = getToolButtonID();
 		
 		if ( !icon().isEmpty() )
@@ -145,7 +145,7 @@ void AutoToolsAction::updateEnabled( int i )
 {
 	TQWidget* w = container( i );
 	
-	if ( ::tqqt_cast<TQToolButton*>( w ) )
+	if ( ::tqt_cast<TQToolButton*>( w ) )
 		static_cast<TQToolButton*>( w )->setEnabled( isEnabled() );
 	else
 		TDEAction::updateEnabled( i ) ;
