@@ -29,7 +29,7 @@ TQ_OBJECT
   
 	
 public:
-	EnvironmentDisplayDialog(TQWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
+	EnvironmentDisplayDialog(TQWidget* parent = 0, const char* name = 0, bool modal = false, WFlags fl = 0 );
 };
 
 #endif
