@@ -31,7 +31,7 @@ Make options widget.
 */
 class MakeOptionsWidget : public MakeOptionsWidgetBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     
 public:
