@@ -16,7 +16,7 @@
 
 class DisableSubprojectDlg : public DisableSubprojectDlgBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
@@ -38,6 +38,3 @@ protected slots:
 };
 
 #endif
-
-
-// kate: space-indent on; indent-width 4; tab-width 4; replace-tabs on
