@@ -56,29 +56,29 @@
 #include <tdelocale.h>
 
 CustomWidgetEditor::CustomWidgetEditor( TQWidget *parent, MainWindow *mw )
-    : CustomWidgetEditorBase( parent, 0, TRUE ), mainWindow( mw )
+    : CustomWidgetEditorBase( parent, 0, true ), mainWindow( mw )
 {
     connect( helpButton, TQ_SIGNAL( clicked() ), MainWindow::self, TQ_SLOT( showDialogHelp() ) );
     checkTimer = new TQTimer( this );
     connect( checkTimer, TQ_SIGNAL( timeout() ),
 	     this, TQ_SLOT( checkWidgetName() ) );
 
-    editClass->setEnabled( FALSE );
-    editHeader->setEnabled( FALSE );
-    buttonChooseHeader->setEnabled( FALSE );
-    buttonChoosePixmap->setEnabled( FALSE );
-    spinWidth->setEnabled( FALSE );
-    spinHeight->setEnabled( FALSE );
-    sizeHor->setEnabled( FALSE );
-    sizeVer->setEnabled( FALSE );
-    checkContainer->setEnabled( FALSE );
-    localGlobalCombo->setEnabled( FALSE );
+    editClass->setEnabled( false );
+    editHeader->setEnabled( false );
+    buttonChooseHeader->setEnabled( false );
+    buttonChoosePixmap->setEnabled( false );
+    spinWidth->setEnabled( false );
+    spinHeight->setEnabled( false );
+    sizeHor->setEnabled( false );
+    sizeVer->setEnabled( false );
+    checkContainer->setEnabled( false );
+    localGlobalCombo->setEnabled( false );
     editClass->setValidator( new AsciiValidator( TQString(":"), editClass ) );
-    editSignal->setValidator( new AsciiValidator( TRUE, editSignal ) );
-    editSlot->setValidator( new AsciiValidator( TRUE, editSignal ) );
+    editSignal->setValidator( new AsciiValidator( true, editSignal ) );
+    editSlot->setValidator( new AsciiValidator( true, editSignal ) );
     editProperty->setValidator( new AsciiValidator( editSignal ) );
-    editSignal->setEnabled( FALSE );
-    buttonRemoveSignal->setEnabled( FALSE );
+    editSignal->setEnabled( false );
+    buttonRemoveSignal->setEnabled( false );
 
     setupDefinition();
     setupSignals();
@@ -100,15 +100,15 @@ void CustomWidgetEditor::setupDefinition()
 
     if ( boxWidgets->firstItem() ) {
 	boxWidgets->setCurrentItem( boxWidgets->firstItem() );
-	boxWidgets->setSelected( boxWidgets->firstItem(), TRUE );
+	boxWidgets->setSelected( boxWidgets->firstItem(), true );
     }
     oldItem = 0;
 }
 
 void CustomWidgetEditor::setupSignals()
 {
-    editSignal->setEnabled( FALSE );
-    buttonRemoveSignal->setEnabled( FALSE );
+    editSignal->setEnabled( false );
+    buttonRemoveSignal->setEnabled( false );
     MetaDataBase::CustomWidget *w = findWidget( boxWidgets->item( boxWidgets->currentItem() ) );
     if ( !w )
 	return;
@@ -117,15 +117,15 @@ void CustomWidgetEditor::setupSignals()
 	listSignals->insertItem( TQString( *it ) );
     if ( listSignals->firstItem() ) {
 	listSignals->setCurrentItem( listSignals->firstItem() );
-	listSignals->setSelected( listSignals->firstItem(), TRUE );
+	listSignals->setSelected( listSignals->firstItem(), true );
     }
 }
 
 void CustomWidgetEditor::setupSlots()
 {
-    editSlot->setEnabled( FALSE );
-    comboAccess->setEnabled( FALSE );
-    buttonRemoveSlot->setEnabled( FALSE );
+    editSlot->setEnabled( false );
+    comboAccess->setEnabled( false );
+    buttonRemoveSlot->setEnabled( false );
 
     MetaDataBase::CustomWidget *w = findWidget( boxWidgets->item( boxWidgets->currentItem() ) );
     if ( !w )
@@ -136,15 +136,15 @@ void CustomWidgetEditor::setupSlots()
 
     if ( listSlots->firstChild() ) {
 	listSlots->setCurrentItem( listSlots->firstChild() );
-	listSlots->setSelected( listSlots->firstChild(), TRUE );
+	listSlots->setSelected( listSlots->firstChild(), true );
     }
 }
 
 void CustomWidgetEditor::setupProperties()
 {
-    editProperty->setEnabled( FALSE );
-    comboType->setEnabled( FALSE );
-    buttonRemoveProperty->setEnabled( FALSE );
+    editProperty->setEnabled( false );
+    comboType->setEnabled( false );
+    buttonRemoveProperty->setEnabled( false );
 
     MetaDataBase::CustomWidget *w = findWidget( boxWidgets->item( boxWidgets->currentItem() ) );
     if ( !w )
@@ -155,7 +155,7 @@ void CustomWidgetEditor::setupProperties()
 
     if ( listProperties->firstChild() ) {
 	listProperties->setCurrentItem( listProperties->firstChild() );
-	listProperties->setSelected( listProperties->firstChild(), TRUE );
+	listProperties->setSelected( listProperties->firstChild(), true );
     }
 }
 
@@ -166,33 +166,33 @@ void CustomWidgetEditor::currentWidgetChanged( TQListBoxItem *i )
 
     MetaDataBase::CustomWidget *w = findWidget( i );
     if ( !i || !w ) {
-	buttonChooseHeader->setEnabled( FALSE );
-	editClass->setEnabled( FALSE );
-	editHeader->setEnabled( FALSE );
-	buttonChoosePixmap->setEnabled( FALSE );
-	spinWidth->setEnabled( FALSE );
-	spinHeight->setEnabled( FALSE );
-	localGlobalCombo->setEnabled( FALSE );
-	sizeHor->setEnabled( FALSE );
-	sizeVer->setEnabled( FALSE );
-	checkContainer->setEnabled( FALSE );
+	buttonChooseHeader->setEnabled( false );
+	editClass->setEnabled( false );
+	editHeader->setEnabled( false );
+	buttonChoosePixmap->setEnabled( false );
+	spinWidth->setEnabled( false );
+	spinHeight->setEnabled( false );
+	localGlobalCombo->setEnabled( false );
+	sizeHor->setEnabled( false );
+	sizeVer->setEnabled( false );
+	checkContainer->setEnabled( false );
 	return;
     }
 
-    buttonChooseHeader->setEnabled( TRUE );
-    editClass->setEnabled( TRUE );
-    editHeader->setEnabled( TRUE );
-    buttonChoosePixmap->setEnabled( TRUE );
-    spinWidth->setEnabled( TRUE );
-    spinHeight->setEnabled( TRUE );
-    localGlobalCombo->setEnabled( TRUE );
-    sizeHor->setEnabled( TRUE );
-    sizeVer->setEnabled( TRUE );
-    checkContainer->setEnabled( TRUE );
+    buttonChooseHeader->setEnabled( true );
+    editClass->setEnabled( true );
+    editHeader->setEnabled( true );
+    buttonChoosePixmap->setEnabled( true );
+    spinWidth->setEnabled( true );
+    spinHeight->setEnabled( true );
+    localGlobalCombo->setEnabled( true );
+    sizeHor->setEnabled( true );
+    sizeVer->setEnabled( true );
+    checkContainer->setEnabled( true );
 
-    editClass->blockSignals( TRUE );
+    editClass->blockSignals( true );
     editClass->setText( w->className );
-    editClass->blockSignals( FALSE );
+    editClass->blockSignals( false );
     editHeader->setText( w->includeFile );
     localGlobalCombo->setCurrentItem( (int)w->includePolicy );
     if ( w->pixmap )
@@ -230,7 +230,7 @@ void CustomWidgetEditor::addWidgetClicked()
     customWidgets.insert( i, w );
 
     boxWidgets->setCurrentItem( i );
-    boxWidgets->setSelected( i, TRUE );
+    boxWidgets->setSelected( i, true );
 }
 
 void CustomWidgetEditor::classNameChanged( const TQString &s )
@@ -243,7 +243,7 @@ void CustomWidgetEditor::classNameChanged( const TQString &s )
     WidgetDatabase::customWidgetClassNameChanged( w->className, s );
 
     checkTimer->stop();
-    boxWidgets->blockSignals( TRUE );
+    boxWidgets->blockSignals( true );
     oldName = w->className;
     w->className = s;
     TQListBoxItem *old = i;
@@ -255,8 +255,8 @@ void CustomWidgetEditor::classNameChanged( const TQString &s )
     oldItem = i;
     customWidgets.insert( i, w );
     customWidgets.remove( old );
-    boxWidgets->blockSignals( FALSE );
-    checkTimer->start( 1000, TRUE );
+    boxWidgets->blockSignals( false );
+    checkTimer->start( 1000, true );
 }
 
 void CustomWidgetEditor::deleteWidgetClicked()
@@ -289,7 +289,7 @@ void CustomWidgetEditor::deleteWidgetClicked()
     i = boxWidgets->item( boxWidgets->currentItem() );
     if ( i ) {
 	boxWidgets->setCurrentItem( i );
-	boxWidgets->setSelected( i, TRUE );
+	boxWidgets->setSelected( i, true );
     }
 }
 
@@ -337,13 +337,13 @@ void CustomWidgetEditor::pixmapChoosen()
     delete w->pixmap;
     w->pixmap = new TQPixmap( pix );
 
-    boxWidgets->blockSignals( TRUE );
+    boxWidgets->blockSignals( true );
     TQListBoxItem *old = i;
     boxWidgets->changeItem( *w->pixmap, w->className, boxWidgets->currentItem() );
     i = boxWidgets->item( boxWidgets->currentItem() );
     customWidgets.insert( i, w );
     customWidgets.remove( old );
-    boxWidgets->blockSignals( FALSE );
+    boxWidgets->blockSignals( false );
     previewPixmap->setPixmap( *w->pixmap );
 }
 
@@ -417,28 +417,28 @@ void CustomWidgetEditor::closeClicked()
 
 void CustomWidgetEditor::currentSignalChanged( TQListBoxItem *i )
 {
-    editSignal->blockSignals( TRUE );
+    editSignal->blockSignals( true );
     editSignal->setText( "" );
-    editSignal->blockSignals( FALSE );
+    editSignal->blockSignals( false );
 
     if ( !i ) {
-	editSignal->setEnabled( FALSE );
-	buttonRemoveSignal->setEnabled( FALSE );
+	editSignal->setEnabled( false );
+	buttonRemoveSignal->setEnabled( false );
 	return;
     }
 
-    editSignal->blockSignals( TRUE );
-    editSignal->setEnabled( TRUE );
-    buttonRemoveSignal->setEnabled( TRUE );
+    editSignal->blockSignals( true );
+    editSignal->setEnabled( true );
+    buttonRemoveSignal->setEnabled( true );
     editSignal->setText( i->text() );
-    editSignal->blockSignals( FALSE );
+    editSignal->blockSignals( false );
 }
 
 void CustomWidgetEditor::addSignal()
 {
     TQListBoxItem *i = new TQListBoxText( listSignals, "signal()" );
     listSignals->setCurrentItem( i );
-    listSignals->setSelected( i, TRUE );
+    listSignals->setSelected( i, true );
     MetaDataBase::CustomWidget *w = findWidget( boxWidgets->item( boxWidgets->currentItem() ) );
     if ( w )
 	w->lstSignals.append( i->text().latin1() );
@@ -449,7 +449,7 @@ void CustomWidgetEditor::removeSignal()
     TQString s = listSignals->currentText();
     delete listSignals->item( listSignals->currentItem() );
     if ( listSignals->currentItem() != -1 )
-	listSignals->setSelected( listSignals->currentItem(), TRUE );
+	listSignals->setSelected( listSignals->currentItem(), true );
     MetaDataBase::CustomWidget *w = findWidget( boxWidgets->item( boxWidgets->currentItem() ) );
     if ( w )
 	w->lstSignals.remove( s.latin1() );
@@ -464,9 +464,9 @@ void CustomWidgetEditor::signalNameChanged( const TQString &s )
     TQValueList<TQCString>::Iterator it = w->lstSignals.find( listSignals->currentText().latin1() );
     if ( it != w->lstSignals.end() )
 	w->lstSignals.remove( it );
-    listSignals->blockSignals( TRUE );
+    listSignals->blockSignals( true );
     listSignals->changeItem( s, listSignals->currentItem() );
-    listSignals->blockSignals( FALSE );
+    listSignals->blockSignals( false );
     w->lstSignals.append( s.latin1() );
 }
 
@@ -511,7 +511,7 @@ void CustomWidgetEditor::addSlot()
 {
     TQListViewItem *i = new TQListViewItem( listSlots, "slot()", "public" );
     listSlots->setCurrentItem( i );
-    listSlots->setSelected( i, TRUE );
+    listSlots->setSelected( i, true );
     MetaDataBase::CustomWidget *w = findWidget( boxWidgets->item( boxWidgets->currentItem() ) );
     if ( w ) {
 	MetaDataBase::Function slot;
@@ -532,7 +532,7 @@ void CustomWidgetEditor::removeSlot()
     }
     delete listSlots->currentItem();
     if ( listSlots->currentItem() )
-	listSlots->setSelected( listSlots->currentItem(), TRUE );
+	listSlots->setSelected( listSlots->currentItem(), true );
     MetaDataBase::CustomWidget *w = findWidget( boxWidgets->item( boxWidgets->currentItem() ) );
     if ( w && slot.function != "1 2 3" )
 	w->lstSlots.remove( slot );
@@ -540,29 +540,29 @@ void CustomWidgetEditor::removeSlot()
 
 void CustomWidgetEditor::currentSlotChanged( TQListViewItem *i )
 {
-    editSlot->blockSignals( TRUE );
+    editSlot->blockSignals( true );
     editSlot->setText( "" );
-    editSignal->blockSignals( FALSE );
+    editSignal->blockSignals( false );
 
     if ( !i ) {
-	editSlot->setEnabled( FALSE );
-	comboAccess->setEnabled( FALSE );
-	buttonRemoveSlot->setEnabled( FALSE );
+	editSlot->setEnabled( false );
+	comboAccess->setEnabled( false );
+	buttonRemoveSlot->setEnabled( false );
 	return;
     }
 
-    editSlot->setEnabled( TRUE );
-    comboAccess->setEnabled( TRUE );
-    buttonRemoveSlot->setEnabled( TRUE );
-    editSlot->blockSignals( TRUE );
-    comboAccess->blockSignals( TRUE );
+    editSlot->setEnabled( true );
+    comboAccess->setEnabled( true );
+    buttonRemoveSlot->setEnabled( true );
+    editSlot->blockSignals( true );
+    comboAccess->blockSignals( true );
     editSlot->setText( i->text( 0 ) );
     if ( i->text( 1 ) == i18n( "protected" ) )
 	comboAccess->setCurrentItem( 1 );
     else
 	comboAccess->setCurrentItem( 0 );
-    editSlot->blockSignals( FALSE );
-    comboAccess->blockSignals( FALSE );
+    editSlot->blockSignals( false );
+    comboAccess->blockSignals( false );
 }
 
 void CustomWidgetEditor::propertyTypeChanged( const TQString &s )
@@ -605,7 +605,7 @@ void CustomWidgetEditor::addProperty()
 {
     TQListViewItem *i = new TQListViewItem( listProperties, "property", "String" );
     listProperties->setCurrentItem( i );
-    listProperties->setSelected( i, TRUE );
+    listProperties->setSelected( i, true );
     MetaDataBase::CustomWidget *w = findWidget( boxWidgets->item( boxWidgets->currentItem() ) );
     if ( w ) {
 	MetaDataBase::Property prop;
@@ -625,7 +625,7 @@ void CustomWidgetEditor::removeProperty()
     }
     delete listProperties->currentItem();
     if ( listProperties->currentItem() )
-	listProperties->setSelected( listProperties->currentItem(), TRUE );
+	listProperties->setSelected( listProperties->currentItem(), true );
     MetaDataBase::CustomWidget *w = findWidget( boxWidgets->item( boxWidgets->currentItem() ) );
     if ( w && property.property != "1 2 3" )
 	w->lstProperties.remove( property );
@@ -633,22 +633,22 @@ void CustomWidgetEditor::removeProperty()
 
 void CustomWidgetEditor::currentPropertyChanged( TQListViewItem *i )
 {
-    editProperty->blockSignals( TRUE );
+    editProperty->blockSignals( true );
     editProperty->setText( "" );
-    editSignal->blockSignals( FALSE );
+    editSignal->blockSignals( false );
 
     if ( !i ) {
-	editProperty->setEnabled( FALSE );
-	comboType->setEnabled( FALSE );
-	buttonRemoveProperty->setEnabled( FALSE );
+	editProperty->setEnabled( false );
+	comboType->setEnabled( false );
+	buttonRemoveProperty->setEnabled( false );
 	return;
     }
 
-    editProperty->setEnabled( TRUE );
-    comboType->setEnabled( TRUE );
-    buttonRemoveProperty->setEnabled( TRUE );
-    editProperty->blockSignals( TRUE );
-    comboType->blockSignals( TRUE );
+    editProperty->setEnabled( true );
+    comboType->setEnabled( true );
+    buttonRemoveProperty->setEnabled( true );
+    editProperty->blockSignals( true );
+    comboType->blockSignals( true );
     editProperty->setText( i->text( 0 ) );
 
     for ( int j = 0; j < comboType->count(); ++j ) {
@@ -657,8 +657,8 @@ void CustomWidgetEditor::currentPropertyChanged( TQListViewItem *i )
 	    break;
 	}
     }
-    editProperty->blockSignals( FALSE );
-    comboType->blockSignals( FALSE );
+    editProperty->blockSignals( false );
+    comboType->blockSignals( false );
 }
 
 static TQString makeIndent2( int indent )
