@@ -128,37 +128,37 @@ void MainWindow::setupEditActions()
     actionEditUndo->setStatusTip( i18n( "Undoes the last action" ) );
     actionEditUndo->setWhatsThis( whatsThisFrom( "Edit|Undo" ) );
     connect( actionEditUndo, TQ_SIGNAL( activated() ), this, TQ_SLOT( editUndo() ) );
-    actionEditUndo->setEnabled( FALSE );
+    actionEditUndo->setEnabled( false );
 
     actionEditRedo = new DesignerAction( i18n( "Redo" ), createIconSet("designer_redo.png"), i18n( "&Redo: Not Available" ), CTRL + Key_Y, this, 0 );
     actionEditRedo->setStatusTip( i18n( "Redoes the last undone operation") );
     actionEditRedo->setWhatsThis( whatsThisFrom( "Edit|Redo" ) );
     connect( actionEditRedo, TQ_SIGNAL( activated() ), this, TQ_SLOT( editRedo() ) );
-    actionEditRedo->setEnabled( FALSE );
+    actionEditRedo->setEnabled( false );
 
     actionEditCut = new DesignerAction( i18n( "Cut" ), createIconSet("designer_editcut.png"), i18n( "Cu&t" ), CTRL + Key_X, this, 0 );
     actionEditCut->setStatusTip( i18n( "Cuts the selected widgets and puts them on the clipboard" ) );
     actionEditCut->setWhatsThis(  whatsThisFrom( "Edit|Cut" ) );
     connect( actionEditCut, TQ_SIGNAL( activated() ), this, TQ_SLOT( editCut() ) );
-    actionEditCut->setEnabled( FALSE );
+    actionEditCut->setEnabled( false );
 
     actionEditCopy = new DesignerAction( i18n( "Copy" ), createIconSet("designer_editcopy.png"), i18n( "&Copy" ), CTRL + Key_C, this, 0 );
     actionEditCopy->setStatusTip( i18n( "Copies the selected widgets to the clipboard" ) );
     actionEditCopy->setWhatsThis(  whatsThisFrom( "Edit|Copy" ) );
     connect( actionEditCopy, TQ_SIGNAL( activated() ), this, TQ_SLOT( editCopy() ) );
-    actionEditCopy->setEnabled( FALSE );
+    actionEditCopy->setEnabled( false );
 
     actionEditPaste = new DesignerAction( i18n( "Paste" ), createIconSet("designer_editpaste.png"), i18n( "&Paste" ), CTRL + Key_V, this, 0 );
     actionEditPaste->setStatusTip( i18n( "Pastes the clipboard's contents" ) );
     actionEditPaste->setWhatsThis( whatsThisFrom( "Edit|Paste" ) );
     connect( actionEditPaste, TQ_SIGNAL( activated() ), this, TQ_SLOT( editPaste() ) );
-    actionEditPaste->setEnabled( FALSE );
+    actionEditPaste->setEnabled( false );
 
     actionEditDelete = new DesignerAction( i18n( "Delete" ), TQPixmap(), i18n( "&Delete" ), Key_Delete, this, 0 );
     actionEditDelete->setStatusTip( i18n( "Deletes the selected widgets" ) );
     actionEditDelete->setWhatsThis( whatsThisFrom( "Edit|Delete" ) );
     connect( actionEditDelete, TQ_SIGNAL( activated() ), this, TQ_SLOT( editDelete() ) );
-    actionEditDelete->setEnabled( FALSE );
+    actionEditDelete->setEnabled( false );
 #ifdef TQ_WS_MAC
     TQAction *macDelete = new DesignerAction( i18n( "Delete" ), TQPixmap(), i18n( "&Delete" ), Key_Backspace, this, 0 );
     connect( macDelete, TQ_SIGNAL( activated() ), this, TQ_SLOT( editDelete() ) );
@@ -168,19 +168,19 @@ void MainWindow::setupEditActions()
     actionEditSelectAll->setStatusTip( i18n( "Selects all widgets" ) );
     actionEditSelectAll->setWhatsThis( whatsThisFrom( "Edit|Select All" ) );
     connect( actionEditSelectAll, TQ_SIGNAL( activated() ), this, TQ_SLOT( editSelectAll() ) );
-    actionEditSelectAll->setEnabled( TRUE );
+    actionEditSelectAll->setEnabled( true );
 
     actionEditRaise = new DesignerAction( i18n( "Bring to Front" ), createIconSet("designer_editraise.png"), i18n( "Bring to &Front" ), 0, this, 0 );
     actionEditRaise->setStatusTip( i18n( "Raises the selected widgets" ) );
     actionEditRaise->setWhatsThis( i18n( "Raises the selected widgets" ) );
     connect( actionEditRaise, TQ_SIGNAL( activated() ), this, TQ_SLOT( editRaise() ) );
-    actionEditRaise->setEnabled( FALSE );
+    actionEditRaise->setEnabled( false );
 
     actionEditLower = new DesignerAction( i18n( "Send to Back" ), createIconSet("designer_editlower.png"), i18n( "Send to &Back" ), 0, this, 0 );
     actionEditLower->setStatusTip( i18n( "Lowers the selected widgets" ) );
     actionEditLower->setWhatsThis( i18n( "Lowers the selected widgets" ) );
     connect( actionEditLower, TQ_SIGNAL( activated() ), this, TQ_SLOT( editLower() ) );
-    actionEditLower->setEnabled( FALSE );
+    actionEditLower->setEnabled( false );
 
     actionEditAccels = new DesignerAction( i18n( "Check Accelerators" ), TQPixmap(),
 				    i18n( "Chec&k Accelerators" ), ALT + Key_R, this, 0 );
@@ -271,25 +271,25 @@ void MainWindow::setupSearchActions()
     actionSearchFind = new DesignerAction( i18n( "Find" ), createIconSet( "designer_searchfind.png" ),
 				    i18n( "&Find..." ), CTRL + Key_F, this, 0 );
     connect( actionSearchFind, TQ_SIGNAL( activated() ), this, TQ_SLOT( searchFind() ) );
-    actionSearchFind->setEnabled( FALSE );
+    actionSearchFind->setEnabled( false );
     actionSearchFind->setWhatsThis( whatsThisFrom( "Search|Find" ) );
 
     actionSearchIncremetal = new DesignerAction( i18n( "Find Incremental" ), TQIconSet(),
 					  i18n( "Find &Incremental" ), ALT + Key_I, this, 0 );
     connect( actionSearchIncremetal, TQ_SIGNAL( activated() ), this, TQ_SLOT( searchIncremetalFindMenu() ) );
-    actionSearchIncremetal->setEnabled( FALSE );
+    actionSearchIncremetal->setEnabled( false );
     actionSearchIncremetal->setWhatsThis( whatsThisFrom( "Search|Find Incremental" ) );
 
     actionSearchReplace = new DesignerAction( i18n( "Replace" ), TQIconSet(),
 				    i18n( "&Replace..." ), CTRL + Key_R, this, 0 );
     connect( actionSearchReplace, TQ_SIGNAL( activated() ), this, TQ_SLOT( searchReplace() ) );
-    actionSearchReplace->setEnabled( FALSE );
+    actionSearchReplace->setEnabled( false );
     actionSearchReplace->setWhatsThis( whatsThisFrom( "Search|Replace" ) );
 
     actionSearchGotoLine = new DesignerAction( i18n( "Goto Line" ), TQIconSet(),
 				    i18n( "&Goto Line..." ), ALT + Key_G, this, 0 );
     connect( actionSearchGotoLine, TQ_SIGNAL( activated() ), this, TQ_SLOT( searchGotoLine() ) );
-    actionSearchGotoLine->setEnabled( FALSE );
+    actionSearchGotoLine->setEnabled( false );
     actionSearchGotoLine->setWhatsThis( whatsThisFrom( "Search|Goto line" ) );
 
 /*    TQToolBar *tb = new TQToolBar( this, "Search" );
@@ -304,7 +304,7 @@ void MainWindow::setupSearchActions()
 	     this, TQ_SLOT( searchIncremetalFind() ) );
     connect( incrementalSearch, TQ_SIGNAL( returnPressed() ),
 	     this, TQ_SLOT( searchIncremetalFindNext() ) );
-    incrementalSearch->setEnabled( FALSE );
+    incrementalSearch->setEnabled( false );
 
     TQPopupMenu *menu = new TQPopupMenu( this, "Search" );
     menubar->insertItem( i18n( "&Search" ), menu );
@@ -319,7 +319,7 @@ void MainWindow::setupLayoutActions()
 {
     if ( !actionGroupTools ) {
 	actionGroupTools = new TQActionGroup( this );
-	actionGroupTools->setExclusive( TRUE );
+	actionGroupTools->setExclusive( true );
 	connect( actionGroupTools, TQ_SIGNAL( selected(TQAction*) ), this, TQ_SLOT( toolSelected(TQAction*) ) );
     }
 
@@ -328,53 +328,53 @@ void MainWindow::setupLayoutActions()
     actionEditAdjustSize->setStatusTip(i18n("Adjusts the size of the selected widget") );
     actionEditAdjustSize->setWhatsThis( whatsThisFrom( "Layout|Adjust Size" ) );
     connect( actionEditAdjustSize, TQ_SIGNAL( activated() ), this, TQ_SLOT( editAdjustSize() ) );
-    actionEditAdjustSize->setEnabled( FALSE );
+    actionEditAdjustSize->setEnabled( false );
 
     actionEditHLayout = new DesignerAction( i18n( "Lay Out Horizontally" ), createIconSet("designer_edithlayout.png"),
 				     i18n( "Lay Out &Horizontally" ), CTRL + Key_H, this, 0 );
     actionEditHLayout->setStatusTip(i18n("Lays out the selected widgets horizontally") );
     actionEditHLayout->setWhatsThis( whatsThisFrom( "Layout|Lay Out Horizontally" ) );
     connect( actionEditHLayout, TQ_SIGNAL( activated() ), this, TQ_SLOT( editLayoutHorizontal() ) );
-    actionEditHLayout->setEnabled( FALSE );
+    actionEditHLayout->setEnabled( false );
 
     actionEditVLayout = new DesignerAction( i18n( "Lay Out Vertically" ), createIconSet("designer_editvlayout.png"),
 				     i18n( "Lay Out &Vertically" ), CTRL + Key_L, this, 0 );
     actionEditVLayout->setStatusTip(i18n("Lays out the selected widgets vertically") );
     actionEditVLayout->setWhatsThis(  whatsThisFrom( "Layout|Lay Out Vertically" ) );
     connect( actionEditVLayout, TQ_SIGNAL( activated() ), this, TQ_SLOT( editLayoutVertical() ) );
-    actionEditVLayout->setEnabled( FALSE );
+    actionEditVLayout->setEnabled( false );
 
     actionEditGridLayout = new DesignerAction( i18n( "Lay Out in a Grid" ), createIconSet("designer_editgrid.png"),
 					i18n( "Lay Out in a &Grid" ), CTRL + Key_G, this, 0 );
     actionEditGridLayout->setStatusTip(i18n("Lays out the selected widgets in a grid") );
     actionEditGridLayout->setWhatsThis( whatsThisFrom( "Layout|Lay Out in a Grid" ) );
     connect( actionEditGridLayout, TQ_SIGNAL( activated() ), this, TQ_SLOT( editLayoutGrid() ) );
-    actionEditGridLayout->setEnabled( FALSE );
+    actionEditGridLayout->setEnabled( false );
 
     actionEditSplitHorizontal = new DesignerAction( i18n( "Lay Out Horizontally (in Splitter)" ), createIconSet("designer_editvlayoutsplit.png"),
 					     i18n( "Lay Out Horizontally (in S&plitter)" ), 0, this, 0 );
     actionEditSplitHorizontal->setStatusTip(i18n("Lays out the selected widgets horizontally in a splitter") );
     actionEditSplitHorizontal->setWhatsThis( whatsThisFrom( "Layout|Lay Out Horizontally (in Splitter)" ) );
     connect( actionEditSplitHorizontal, TQ_SIGNAL( activated() ), this, TQ_SLOT( editLayoutHorizontalSplit() ) );
-    actionEditSplitHorizontal->setEnabled( FALSE );
+    actionEditSplitHorizontal->setEnabled( false );
 
     actionEditSplitVertical = new DesignerAction( i18n( "Lay Out Vertically (in Splitter)" ), createIconSet("designer_edithlayoutsplit.png"),
 					     i18n( "Lay Out Vertically (in Sp&litter)" ), 0, this, 0 );
     actionEditSplitVertical->setStatusTip(i18n("Lays out the selected widgets vertically in a splitter") );
     actionEditSplitVertical->setWhatsThis( whatsThisFrom( "Layout|Lay Out Vertically (in Splitter)" ) );
     connect( actionEditSplitVertical, TQ_SIGNAL( activated() ), this, TQ_SLOT( editLayoutVerticalSplit() ) );
-    actionEditSplitVertical->setEnabled( FALSE );
+    actionEditSplitVertical->setEnabled( false );
 
     actionEditBreakLayout = new DesignerAction( i18n( "Break Layout" ), createIconSet("designer_editbreaklayout.png"),
 					 i18n( "&Break Layout" ), CTRL + Key_B, this, 0 );
     actionEditBreakLayout->setStatusTip(i18n("Breaks the selected layout") );
     actionEditBreakLayout->setWhatsThis( whatsThisFrom( "Layout|Break Layout" ) );
     connect( actionEditBreakLayout, TQ_SIGNAL( activated() ), this, TQ_SLOT( editBreakLayout() ) );
-    actionEditBreakLayout->setEnabled( FALSE );
+    actionEditBreakLayout->setEnabled( false );
 
     int id = WidgetDatabase::idFromClassName( "Spacer" );
     actionInsertSpacer = new WidgetAction( i18n( "Layout" ), actionGroupTools, TQString::number( id ).latin1() );
-    actionInsertSpacer->setToggleAction( TRUE );
+    actionInsertSpacer->setToggleAction( true );
     actionInsertSpacer->setText( WidgetDatabase::className( id ) );
     actionInsertSpacer->setMenuText( i18n( "Add %1").arg( WidgetDatabase::className( id ) ) );
     actionInsertSpacer->setIconSet( WidgetDatabase::iconSet( id ) );
@@ -423,7 +423,7 @@ void MainWindow::setupToolActions()
 {
     if ( !actionGroupTools ) {
 	actionGroupTools = new TQActionGroup( this );
-	actionGroupTools->setExclusive( TRUE );
+	actionGroupTools->setExclusive( true );
 	connect( actionGroupTools, TQ_SIGNAL( selected(TQAction*) ),
 		 this, TQ_SLOT( toolSelected(TQAction*) ) );
     }
@@ -431,7 +431,7 @@ void MainWindow::setupToolActions()
     actionPointerTool = new DesignerAction( i18n("Pointer"), createIconSet("designer_pointer.png"),
 				     i18n("&Pointer"),  Key_F2,
 				     actionGroupTools,
-				     TQString::number(POINTER_TOOL).latin1(), TRUE );
+				     TQString::number(POINTER_TOOL).latin1(), true );
     actionPointerTool->setStatusTip( i18n("Selects the pointer tool") );
     actionPointerTool->setWhatsThis( whatsThisFrom( "Tools|Pointer" ) );
 
@@ -440,21 +440,21 @@ void MainWindow::setupToolActions()
 				     i18n("&Connect Signal/Slots"),
 				     singleProjectMode() ? 0 : Key_F3,
 				     actionGroupTools,
-				     TQString::number(CONNECT_TOOL).latin1(), TRUE );
+				     TQString::number(CONNECT_TOOL).latin1(), true );
     actionConnectTool->setStatusTip( i18n("Selects the connection tool") );
     actionConnectTool->setWhatsThis( whatsThisFrom( "Tools|Connect Signals and Slots" ) );
 
     actionOrderTool = new DesignerAction( i18n("Tab Order"), createIconSet("designer_ordertool.png"),
 				   i18n("Tab &Order"),  Key_F4,
 				   actionGroupTools,
-				   TQString::number(ORDER_TOOL).latin1(), TRUE );
+				   TQString::number(ORDER_TOOL).latin1(), true );
     actionOrderTool->setStatusTip( i18n("Selects the tab order tool") );
     actionOrderTool->setWhatsThis( whatsThisFrom( "Tools|Tab Order" ) );
 
     actionBuddyTool = new DesignerAction( i18n( "Set Buddy" ), createIconSet( "designer_setbuddy.png" ),
 				   i18n( "Set &Buddy" ), Key_F12,
 				   actionGroupTools, TQString::number( BUDDY_TOOL ).latin1(),
-				   TRUE );
+				   true );
     actionBuddyTool->setStatusTip( i18n( "Sets a buddy to a label" ) );
     actionBuddyTool->setWhatsThis( whatsThisFrom( "Tools|Set Buddy" ) );
 
@@ -463,7 +463,7 @@ void MainWindow::setupToolActions()
     toolsToolBar = tb;
     TQWhatsThis::add( tb, i18n( "<b>The Tools toolbar</b>%1" ).arg(i18n(toolbarHelp).arg("")) );
 
-    addToolBar( tb, i18n( "Tools" ), TQMainWindow::DockTop, FALSE );
+    addToolBar( tb, i18n( "Tools" ), TQMainWindow::DockTop, false );
     actionPointerTool->addTo( tb );
     if ( !singleProjectMode() )
 	actionConnectTool->addTo( tb );
@@ -518,7 +518,7 @@ void MainWindow::setupToolActions()
 	TQPopupMenu *menu = new TQPopupMenu( this, grp.latin1() );
 	mmenu->insertItem( grp, menu );
 
-	TQToolBar *tb2 = new TQToolBar( grp, 0, toolBox, FALSE, grp.latin1() );
+	TQToolBar *tb2 = new TQToolBar( grp, 0, toolBox, false, grp.latin1() );
 	tb2->setFrameStyle( TQFrame::NoFrame );
 	tb2->setOrientation( TQt::Vertical );
 	tb2->setBackgroundMode( PaletteBase );
@@ -538,7 +538,7 @@ void MainWindow::setupToolActions()
 		continue; // only widgets, i.e. not forms and temp stuff
 	    WidgetAction* a =
 		new WidgetAction( grp, actionGroupTools, TQString::number( i ).latin1() );
-	    a->setToggleAction( TRUE );
+	    a->setToggleAction( true );
 	    TQString atext = WidgetDatabase::className( i );
 	    if ( atext[0] == 'Q' )
 		atext = atext.mid(1);
@@ -594,7 +594,7 @@ void MainWindow::setupToolActions()
 	actionToolsCustomWidget->addTo( customWidgetMenu );
 	customWidgetMenu->insertSeparator();
 	TQToolBar *tb2 = new TQToolBar( "Custom Widgets", 0,
-				      toolBox, FALSE, "Custom Widgets" );
+				      toolBox, false, "Custom Widgets" );
 	tb2->setBackgroundMode(PaletteBase);
 	tb2->setOrientation( TQt::Vertical );
 	tb2->setFrameStyle( TQFrame::NoFrame );
@@ -638,9 +638,9 @@ void MainWindow::setupFileActions()
 	a->addTo( fileMenu );
 	actionNewFile = a;
     } else {
-	actionGroupNew = new TQActionGroup( this, 0, FALSE );
+	actionGroupNew = new TQActionGroup( this, 0, false );
 	TQActionGroup* a = actionGroupNew;
-	( (TQActionGroup*)a )->setUsesDropDown( TRUE );
+	( (TQActionGroup*)a )->setUsesDropDown( true );
 	a->setText( i18n( "New" ) );
 	a->setMenuText( i18n( "&New..." ) );
 	a->setIconSet( createIconSet("designer_form.png") );
@@ -790,14 +790,14 @@ void MainWindow::setupProjectActions()
     TQActionGroup *ag = new TQActionGroup( this, 0 );
     ag->setText( i18n( "Active Project" ) );
     ag->setMenuText( i18n( "Active Project" ) );
-    ag->setExclusive( TRUE );
-    ag->setUsesDropDown( TRUE );
+    ag->setExclusive( true );
+    ag->setUsesDropDown( true );
     connect( ag, TQ_SIGNAL( selected( TQAction * ) ), this, TQ_SLOT( projectSelected( TQAction * ) ) );
     connect( ag, TQ_SIGNAL( selected( TQAction * ) ), this, TQ_SIGNAL( projectChanged() ) );
-    DesignerAction *a = new DesignerAction( i18n( "<No Project>" ), i18n( "<No Project>" ), 0, ag, 0, TRUE );
-    eProject = new Project( "", i18n( "<No Project>" ), projectSettingsPluginManager, TRUE );
+    DesignerAction *a = new DesignerAction( i18n( "<No Project>" ), i18n( "<No Project>" ), 0, ag, 0, true );
+    eProject = new Project( "", i18n( "<No Project>" ), projectSettingsPluginManager, true );
     projects.insert( a, eProject );
-    a->setOn( TRUE );
+    a->setOn( true );
     ag->addTo( projectMenu );
     ag->addTo( projectToolBar );
     actionGroupProjects = ag;
@@ -810,7 +810,7 @@ void MainWindow::setupProjectActions()
     a->setStatusTip( i18n("Adds a file to the current project") );
     a->setWhatsThis( whatsThisFrom( "Project|Add File" ) );
     connect( a, TQ_SIGNAL( activated() ), this, TQ_SLOT( projectInsertFile() ) );
-    a->setEnabled( FALSE );
+    a->setEnabled( false );
     connect( this, TQ_SIGNAL( hasNonDummyProject(bool) ), a, TQ_SLOT( setEnabled(bool) ) );
     if ( !singleProject )
 	a->addTo( projectMenu );
@@ -820,7 +820,7 @@ void MainWindow::setupProjectActions()
     actionEditPixmapCollection->setStatusTip( i18n("Opens a dialog for editing the current project's image collection") );
     actionEditPixmapCollection->setWhatsThis( whatsThisFrom( "Project|Image Collection" ) );
     connect( actionEditPixmapCollection, TQ_SIGNAL( activated() ), this, TQ_SLOT( editPixmapCollection() ) );
-    actionEditPixmapCollection->setEnabled( FALSE );
+    actionEditPixmapCollection->setEnabled( false );
     connect( this, TQ_SIGNAL( hasNonDummyProject(bool) ), actionEditPixmapCollection, TQ_SLOT( setEnabled(bool) ) );
     actionEditPixmapCollection->addTo( projectMenu );
 
@@ -830,7 +830,7 @@ void MainWindow::setupProjectActions()
     actionEditDatabaseConnections->setStatusTip( i18n("Opens a dialog for editing the current project's database connections") );
     actionEditDatabaseConnections->setWhatsThis( whatsThisFrom( "Project|Database Connections" ) );
     connect( actionEditDatabaseConnections, TQ_SIGNAL( activated() ), this, TQ_SLOT( editDatabaseConnections() ) );
-    //actionEditDatabaseConnections->setEnabled( FALSE );
+    //actionEditDatabaseConnections->setEnabled( false );
     //connect( this, TQ_SIGNAL( hasNonDummyProject(bool) ), actionEditDatabaseConnections, TQ_SLOT( setEnabled(bool) ) );
     if ( !singleProject )
 	actionEditDatabaseConnections->addTo( projectMenu );
@@ -841,7 +841,7 @@ void MainWindow::setupProjectActions()
     actionEditProjectSettings->setStatusTip( i18n("Opens a dialog to change the project's settings") );
     actionEditProjectSettings->setWhatsThis( whatsThisFrom( "Project|Project Settings" ) );
     connect( actionEditProjectSettings, TQ_SIGNAL( activated() ), this, TQ_SLOT( editProjectSettings() ) );
-    actionEditProjectSettings->setEnabled( FALSE );
+    actionEditProjectSettings->setEnabled( false );
     connect( this, TQ_SIGNAL( hasNonDummyProject(bool) ), actionEditProjectSettings, TQ_SLOT( setEnabled(bool) ) );
     actionEditProjectSettings->addTo( projectMenu );
 
@@ -898,9 +898,9 @@ void MainWindow::setupPreviewActions()
 
 void MainWindow::setupWindowActions()
 {
-/*    static bool windowActionsSetup = FALSE;
+/*    static bool windowActionsSetup = false;
     if ( !windowActionsSetup ) {
-	windowActionsSetup = TRUE;
+	windowActionsSetup = true;
 */
 	actionWindowTile = new DesignerAction( i18n( "Tile" ), i18n( "&Tile" ), 0, this );
 	actionWindowTile->setStatusTip( i18n("Tiles the windows so that they are all visible") );
@@ -1038,10 +1038,10 @@ void MainWindow::fileNewDialog()
     while ( currentProject->findFormFile( n + ".ui" ) )
 	n = "Dialog" + TQString::number( ++forms );
     FormWindow *fw = 0;
-    FormFile *ff = new FormFile( n + ".ui", FALSE, currentProject );
+    FormFile *ff = new FormFile( n + ".ui", false, currentProject );
     fw = new FormWindow( ff, MainWindow::self, MainWindow::self->qWorkspace(), n );
-    ff->setModified( TRUE );
-    currentProject->setModified( TRUE );
+    ff->setModified( true );
+    currentProject->setModified( true );
     workspace()->update();
     fw->setProject( currentProject );
     MetaDataBase::addEntry( fw );
@@ -1051,10 +1051,10 @@ void MainWindow::fileNewDialog()
     fw->resize( 600, 480 );
     insertFormWindow( fw );
     fw->killAccels( fw );
-    fw->project()->setModified( TRUE );
+    fw->project()->setModified( true );
     fw->setFocus();
-    fw->setSavePixmapInProject( TRUE );
-    fw->setSavePixmapInline( FALSE );
+    fw->setSavePixmapInProject( true );
+    fw->setSavePixmapInline( false );
 }
 
 void MainWindow::fileNewFile()
@@ -1064,10 +1064,10 @@ void MainWindow::fileNewFile()
 	return;
     if ( name.right( 3 ) != ".qs" )
 	name += ".qs";
-    SourceFile *f = new SourceFile( name, FALSE, currentProject );
+    SourceFile *f = new SourceFile( name, false, currentProject );
     MainWindow::self->editSource( f );
-    f->setModified( TRUE );
-    currentProject->setModified( TRUE );
+    f->setModified( true );
+    currentProject->setModified( true );
     workspace()->update();
 }
 
@@ -1127,7 +1127,7 @@ void MainWindow::fileCloseProject()
 	}
 
 	TQWidgetList windows = qWorkspace()->windowList();
-	qWorkspace()->blockSignals( TRUE );
+	qWorkspace()->blockSignals( true );
 	TQWidgetListIt wit( windows );
 	while ( wit.current() ) {
 	    TQWidget *w = wit.current();
@@ -1146,7 +1146,7 @@ void MainWindow::fileCloseProject()
 	}
 	hierarchyView->clear();
 	windows = qWorkspace()->windowList();
-	qWorkspace()->blockSignals( FALSE );
+	qWorkspace()->blockSignals( false );
 	actionGroupProjects->removeChild( a );
 	projects.remove( a );
 	delete a;
@@ -1164,16 +1164,16 @@ void MainWindow::fileCloseProject()
 		break;
 	    }
 	} else {
-	    emit hasActiveWindow( FALSE );
-	    emit hasActiveForm( FALSE );
-	    updateUndoRedo( FALSE, FALSE, TQString(), TQString() );
+	    emit hasActiveWindow( false );
+	    emit hasActiveForm( false );
+	    updateUndoRedo( false, false, TQString(), TQString() );
 	}
     }
 }
 
 void MainWindow::fileOpen() // as called by the menu
 {
-    fileOpen( "", "", "", FALSE );
+    fileOpen( "", "", "", false );
 }
 
 void MainWindow::projectInsertFile()
@@ -1233,24 +1233,24 @@ void MainWindow::fileOpen( const TQString &filter, const TQString &extension, co
 	    if ( !filename.isEmpty() ) {
 		TQFileInfo fi( filename );
 
-		if ( fi.extension( FALSE ) == "pro" && ( extension.isEmpty() || extension.find( ";pro" ) != -1 ) ) {
+		if ( fi.extension( false ) == "pro" && ( extension.isEmpty() || extension.find( ";pro" ) != -1 ) ) {
 		    addRecentlyOpened( filename, recentlyProjects );
 		    openProject( filename );
-		} else if ( fi.extension( FALSE ) == "ui" && ( extension.isEmpty() || extension.find( ";ui" ) != -1 ) ) {
+		} else if ( fi.extension( false ) == "ui" && ( extension.isEmpty() || extension.find( ";ui" ) != -1 ) ) {
 		    if ( !inProject )
 			setCurrentProject( eProject );
 		    openFormWindow( filename );
 		    addRecentlyOpened( filename, recentlyFiles );
-		} else if ( !extension.isEmpty() && extension.find( ";" + fi.extension( FALSE ) ) != -1 ||
-			    additionalSources.find( fi.extension( FALSE ) ) != additionalSources.end() ) {
+		} else if ( !extension.isEmpty() && extension.find( ";" + fi.extension( false ) ) != -1 ||
+			    additionalSources.find( fi.extension( false ) ) != additionalSources.end() ) {
 		    SourceFile *sf = project->findSourceFile( project->makeRelative( filename ) );
 		    if ( !sf )
-			sf = new SourceFile( project->makeRelative( filename ), FALSE, project );
+			sf = new SourceFile( project->makeRelative( filename ), false, project );
 		    editSource( sf );
 		} else if ( extension.isEmpty() ) {
 		    TQString filter;
 		    for ( TQStringList::Iterator it2 = filterlist.begin(); it2 != filterlist.end(); ++it2 ) {
-			if ( (*it2).contains( "." + fi.extension( FALSE ), FALSE ) ) {
+			if ( (*it2).contains( "." + fi.extension( false ), false ) ) {
 			    filter = *it2;
 			    break;
 			}
@@ -1274,7 +1274,7 @@ void MainWindow::fileOpen( const TQString &filter, const TQString &extension, co
 			setCurrentProject( eProject );
 		    addRecentlyOpened( filename, recentlyFiles );
 		    for ( TQStringList::Iterator it = list.begin(); it != list.end(); ++it ) {
-			openFormWindow( *it, FALSE );
+			openFormWindow( *it, false );
 			TQFile::remove( *it );
 		    }
 		    statusBar()->clear();
@@ -1289,10 +1289,10 @@ FormWindow *MainWindow::openFormWindow( const TQString &filename, bool validFile
     if ( filename.isEmpty() )
 	return 0;
 
-    bool makeNew = FALSE;
+    bool makeNew = false;
 
     if ( !TQFile::exists( filename ) ) {
-	makeNew = TRUE;
+	makeNew = true;
     } else {
 	TQFile f( filename );
 	f.open( IO_ReadOnly );
@@ -1318,7 +1318,7 @@ FormWindow *MainWindow::openFormWindow( const TQString &filename, bool validFile
     TQApplication::setOverrideCursor( WaitCursor );
     Resource resource( this );
     if ( !ff )
-	ff = new FormFile( currentProject->makeRelative( filename ), FALSE, currentProject );
+	ff = new FormFile( currentProject->makeRelative( filename ), false, currentProject );
     bool b = resource.load( ff ) && (FormWindow*)resource.widget();
     if ( !validFileName && resource.widget() )
 	( (FormWindow*)resource.widget() )->setFileName( TQString() );
@@ -1360,7 +1360,7 @@ bool MainWindow::fileSaveForm()
 		fw = se->formWindow();
 	    else if ( se->sourceFile() ) {
 		se->sourceFile()->save();
-		return TRUE;
+		return true;
 	    }
 	}
     }
@@ -1368,16 +1368,16 @@ bool MainWindow::fileSaveForm()
     if ( !fw )
 	fw = formWindow();
     if ( !fw || !fw->formFile()->save() )
-	return FALSE;
+	return false;
     TQApplication::restoreOverrideCursor();
-    return TRUE;
+    return true;
 }
 
 bool MainWindow::fileSaveProject()
 {
     currentProject->save();
     statusMessage( i18n( "Project '%1' saved.").arg( currentProject->projectName() )/*, 3000 */);
-    return TRUE;
+    return true;
 }
 
 bool MainWindow::fileSaveAs()
@@ -1386,12 +1386,12 @@ bool MainWindow::fileSaveAs()
 
     TQWidget *w = qworkspace->activeWindow();
     if ( !w )
-	return TRUE;
+	return true;
     if ( ::tqt_cast<FormWindow*>(w) )
 	return ( (FormWindow*)w )->formFile()->saveAs();
     else if ( ::tqt_cast<SourceEditor*>(w) )
 	return ( (SourceEditor*)w )->saveAs();
-    return FALSE;
+    return false;
 }
 
 void MainWindow::fileSaveAll()
@@ -1402,7 +1402,7 @@ void MainWindow::fileSaveAll()
 
 void MainWindow::fileCreateTemplate()
 {
-    CreateTemplate dia( this, 0, TRUE );
+    CreateTemplate dia( this, 0, true );
 
     int i = 0;
     for ( i = 0; i < WidgetDatabase::count(); ++i ) {
@@ -1550,7 +1550,7 @@ void MainWindow::editPaste()
     if ( w && WidgetFactory::layoutType( w ) == WidgetFactory::NoLayout ) {
 	formWindow()->paste( tqApp->clipboard()->text(), WidgetFactory::containerOfWidget( w ) );
 	hierarchyView->widgetInserted( 0 );
-	formWindow()->commandHistory()->setModified( TRUE );
+	formWindow()->commandHistory()->setModified( true );
     } else {
 	TQMessageBox::information( this, i18n( "Paste Error" ),
 				  i18n( "Cannot paste widgets. Designer could not find a container\n"
@@ -1715,7 +1715,7 @@ void MainWindow::editFunctions()
 	return;
 
     statusMessage( i18n( "Edit the current form's slots..." ) );
-    EditFunctions dlg( this, formWindow(), TRUE );
+    EditFunctions dlg( this, formWindow(), true );
     dlg.exec();
     statusBar()->clear();
 }
@@ -1809,7 +1809,7 @@ SourceEditor *MainWindow::createSourceEditor( TQObject *object, Project *project
     if ( editor->object() != object )
 	editor->setObject( object, project );
     else if ( rereadSource )
-	editor->refresh( FALSE );
+	editor->refresh( false );
 
     editor->show();
     editor->setFocus();
@@ -1839,7 +1839,7 @@ void MainWindow::editProjectSettings()
 
 void MainWindow::editPixmapCollection()
 {
-    PixmapCollectionEditor dia( this, 0, TRUE );
+    PixmapCollectionEditor dia( this, 0, true );
     dia.setProject( currentProject );
     dia.exec();
 }
@@ -1847,7 +1847,7 @@ void MainWindow::editPixmapCollection()
 void MainWindow::editDatabaseConnections()
 {
 #ifndef TQT_NO_SQL
-    DatabaseConnectionsEditor dia( currentProject, this, 0, TRUE );
+    DatabaseConnectionsEditor dia( currentProject, this, 0, true );
     dia.exec();
 #endif
 }
@@ -1855,7 +1855,7 @@ void MainWindow::editDatabaseConnections()
 void MainWindow::editPreferences()
 {
     statusMessage( i18n( "Edit preferences..." ) );
-    Preferences *dia = new Preferences( this, 0, TRUE );
+    Preferences *dia = new Preferences( this, 0, true );
     prefDia = dia;
     connect( dia->helpButton, TQ_SIGNAL( clicked() ), MainWindow::self, TQ_SLOT( showDialogHelp() ) );
     dia->buttonColor->setEditor( StyledButton::ColorEditor );
@@ -1872,9 +1872,9 @@ void MainWindow::editPreferences()
     if ( qworkspace->backgroundPixmap() )
 	dia->buttonPixmap->setPixmap( *qworkspace->backgroundPixmap() );
     if ( backPix )
-	dia->radioPixmap->setChecked( TRUE );
+	dia->radioPixmap->setChecked( true );
     else
-	dia->radioColor->setChecked( TRUE );
+	dia->radioColor->setChecked( true );
     dia->checkBoxSplash->setChecked( splashScreen );
     dia->checkAutoEdit->setChecked( !databaseAutoEdit );
     dia->checkBoxStartDialog->setChecked( shStartDialog );
@@ -1909,15 +1909,15 @@ void MainWindow::editPreferences()
 	if (dia->textEditPluginPaths->isModified()) {
 	    pluginPaths = dia->textEditPluginPaths->text();
 	    TQApplication::setLibraryPaths(TQStringList::split("\n", pluginPaths));
-	    savePluginPaths = TRUE;
+	    savePluginPaths = true;
 	}
 
 	if ( dia->radioPixmap->isChecked() && dia->buttonPixmap->pixmap() ) {
 	    qworkspace->setBackgroundPixmap( *dia->buttonPixmap->pixmap() );
-	    backPix = TRUE;
+	    backPix = true;
 	} else {
 	    qworkspace->setBackgroundColor( dia->buttonColor->color() );
-	    backPix = FALSE;
+	    backPix = false;
 	}
 	splashScreen = dia->checkBoxSplash->isChecked();
 	databaseAutoEdit = !dia->checkAutoEdit->isChecked();
@@ -1934,7 +1934,7 @@ void MainWindow::editPreferences()
     for ( it = preferenceTabs.begin(); it != preferenceTabs.end(); ++it ) {
 	Tab t = *it;
 	dia->tabWidget->removePage( t.w );
-	t.w->reparent( 0, TQPoint(0,0), FALSE );
+	t.w->reparent( 0, TQPoint(0,0), false );
     }
 
     for ( SourceEditor *e = sourceEditors.first(); e; e = sourceEditors.next() )
@@ -1952,7 +1952,7 @@ void MainWindow::searchFind()
 	 return;
 
     if ( !findDialog )
-	findDialog = new FindDialog( this, 0, FALSE );
+	findDialog = new FindDialog( this, 0, false );
     findDialog->show();
     findDialog->raise();
     findDialog->setEditor( ( (SourceEditor*)qWorkspace()->activeWindow() )->editorInterface(),
@@ -1974,7 +1974,7 @@ void MainWindow::searchIncremetalFind()
 	 return;
 
     ( (SourceEditor*)qWorkspace()->activeWindow() )->editorInterface()->find( incrementalSearch->text(),
-									     FALSE, FALSE, TRUE, FALSE );
+									     false, false, true, false );
 }
 
 void MainWindow::searchIncremetalFindNext()
@@ -1984,7 +1984,7 @@ void MainWindow::searchIncremetalFindNext()
 	 return;
 
     ( (SourceEditor*)qWorkspace()->activeWindow() )->editorInterface()->find( incrementalSearch->text(),
-									     FALSE, FALSE, TRUE, TRUE );
+									     false, false, true, true );
 }
 
 void MainWindow::searchReplace()
@@ -1994,7 +1994,7 @@ void MainWindow::searchReplace()
 	 return;
 
     if ( !replaceDialog )
-	replaceDialog = new ReplaceDialog( this, 0, FALSE );
+	replaceDialog = new ReplaceDialog( this, 0, false );
     replaceDialog->show();
     replaceDialog->raise();
     replaceDialog->setEditor( ( (SourceEditor*)qWorkspace()->activeWindow() )->editorInterface(),
@@ -2010,7 +2010,7 @@ void MainWindow::searchGotoLine()
 	 return;
 
     if ( !gotoLineDialog )
-	gotoLineDialog = new GotoLineDialog( this, 0, FALSE );
+	gotoLineDialog = new GotoLineDialog( this, 0, false );
     gotoLineDialog->show();
     gotoLineDialog->raise();
     gotoLineDialog->setEditor( ( (SourceEditor*)qWorkspace()->activeWindow() )->editorInterface() );
