@@ -30,6 +30,6 @@
 #include <tqwidgetinterface_p.h>
 
 #define WidgetInterface TQWidgetFactoryInterface
-#define IID_Widget IID_TQWidgetFactory
+#define IID_Widget IID_QWidgetFactory
 
 #endif
