@@ -192,7 +192,7 @@ void KDevDesigner::fileOpen()
     KURL url =
         KFileDialog::getOpenURL( TQString(), TQString(), this );
 
-    if (url.isEmpty() == false)
+    if (!url.isEmpty())
     {
         // About this function, the style guide (
         // http://developer.kde.org/documentation/standards/kde/style/basics/index.html )
