@@ -43,19 +43,19 @@ BashSupportPart::BashSupportPart(TQObject *parent, const char *name, const TQStr
 	setXMLFile("kdevbashsupport.rc");
 
 	TDEAction *action;
-	action = new TDEAction( i18n("&Run"), "application-x-executable",Key_F9,this, TQT_SLOT(slotRun()),actionCollection(), "build_execute" );
+	action = new TDEAction( i18n("&Run"), "application-x-executable",Key_F9,this, TQ_SLOT(slotRun()),actionCollection(), "build_execute" );
     action->setToolTip(i18n("Run"));
     action->setWhatsThis(i18n("<b>Run</b><p>Starts an application."));
 
 	kdDebug() << "Creating BashSupportPart" << endl;
 
-	connect( core(), TQT_SIGNAL(projectConfigWidget(KDialogBase*)),
-		this, TQT_SLOT(projectConfigWidget(KDialogBase*)) );
-	connect( core(), TQT_SIGNAL(projectOpened()), this, TQT_SLOT(projectOpened()) );
-	connect( core(), TQT_SIGNAL(projectClosed()), this, TQT_SLOT(projectClosed()) );
-	connect( partController(), TQT_SIGNAL(savedFile(const KURL&)), this, TQT_SLOT(savedFile(const KURL&)) );
- 	connect(partController(), TQT_SIGNAL(activePartChanged(KParts::Part*)),
-		this, TQT_SLOT(slotActivePartChanged(KParts::Part *)));
+	connect( core(), TQ_SIGNAL(projectConfigWidget(KDialogBase*)),
+		this, TQ_SLOT(projectConfigWidget(KDialogBase*)) );
+	connect( core(), TQ_SIGNAL(projectOpened()), this, TQ_SLOT(projectOpened()) );
+	connect( core(), TQ_SIGNAL(projectClosed()), this, TQ_SLOT(projectClosed()) );
+	connect( partController(), TQ_SIGNAL(savedFile(const KURL&)), this, TQ_SLOT(savedFile(const KURL&)) );
+ 	connect(partController(), TQ_SIGNAL(activePartChanged(KParts::Part*)),
+		this, TQ_SLOT(slotActivePartChanged(KParts::Part *)));
 
 	m_cc = new BashCodeCompletion();
 }
@@ -73,21 +73,21 @@ void BashSupportPart::projectConfigWidget(KDialogBase *dlg)
     Q_UNUSED( dlg );
 //	TQVBox *vbox = dlg->addVBoxPage(i18n("Bash"));
 //	RubyConfigWidget *w = new RubyConfigWidget(*projectDom(), (TQWidget *)vbox, "Bash config widget");
-//	connect( dlg, TQT_SIGNAL(okClicked()), w, TQT_SLOT(accept()) );
+//	connect( dlg, TQ_SIGNAL(okClicked()), w, TQ_SLOT(accept()) );
 }
 
 void BashSupportPart::projectOpened()
 {
 	kdDebug(9014) << "projectOpened()" << endl;
 
-	connect( project(), TQT_SIGNAL(addedFilesToProject(const TQStringList &)),
-		this, TQT_SLOT(addedFilesToProject(const TQStringList &)) );
-	connect( project(), TQT_SIGNAL(removedFilesFromProject(const TQStringList &)),
-		this, TQT_SLOT(removedFilesFromProject(const TQStringList &)) );
+	connect( project(), TQ_SIGNAL(addedFilesToProject(const TQStringList &)),
+		this, TQ_SLOT(addedFilesToProject(const TQStringList &)) );
+	connect( project(), TQ_SIGNAL(removedFilesFromProject(const TQStringList &)),
+		this, TQ_SLOT(removedFilesFromProject(const TQStringList &)) );
 
 	// We want to parse only after all components have been
 	// properly initialized
-	TQTimer::singleShot(0, this, TQT_SLOT(parse()));
+	TQTimer::singleShot(0, this, TQ_SLOT(parse()));
 }
 
 
@@ -183,7 +183,7 @@ void BashSupportPart::startApplication(const TQString &program)
 {
 	kdDebug() << "starting application" << program << endl;
 	if (KDevAppFrontend *appFrontend = extension<KDevAppFrontend>("TDevelop/AppFrontend"))
-		appFrontend->startAppCommand(TQString(), program, TRUE);
+		appFrontend->startAppCommand(TQString(), program, true);
 }
 
 
@@ -332,11 +332,11 @@ void BashCodeCompletion::setActiveEditorPart(KParts::Part *part)
 	}
 
 	disconnect(part->widget(), 0, this, 0 ); // to make sure that it is't connected twice
-	connect(part->widget(), TQT_SIGNAL(cursorPositionChanged()),
-		this, TQT_SLOT(cursorPositionChanged()));
-	connect(part->widget(), TQT_SIGNAL(argHintHidden()), this, TQT_SLOT(argHintHidden()));
-	connect(part->widget(), TQT_SIGNAL(completionAborted()), this, TQT_SLOT(completionBoxAbort()));
-	connect(part->widget(), TQT_SIGNAL(completionDone()), this, TQT_SLOT(completionBoxHidden()));
+	connect(part->widget(), TQ_SIGNAL(cursorPositionChanged()),
+		this, TQ_SLOT(cursorPositionChanged()));
+	connect(part->widget(), TQ_SIGNAL(argHintHidden()), this, TQ_SLOT(argHintHidden()));
+	connect(part->widget(), TQ_SIGNAL(completionAborted()), this, TQ_SLOT(completionBoxAbort()));
+	connect(part->widget(), TQ_SIGNAL(completionDone()), this, TQ_SLOT(completionBoxHidden()));
 
 }
 
