@@ -9,7 +9,7 @@ class CppSupportPart;
 
 class KDevCppSupportIface : public TQObject, public DCOPObject
 {
-	Q_OBJECT
+	TQ_OBJECT
 //	
 	K_DCOP
 public:
@@ -25,4 +25,3 @@ private:
 };
 
 #endif 
-// kate: indent-mode csands; tab-width 4;
