@@ -13,14 +13,14 @@
 
 class %{APPNAME} : public KonqSidebarPlugin
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     
 public:
     /**
      * Construct a @ref KonqSidebarPlugin.
      *
-     * @param inst The sidebar's kinstance class.
+     * @param inst The sidebar's tdeinstance class.
      * @param parent The sidebar internal button info class responsible for this plugin.
      * @param widgetParent The container which will contain the plugins widget.
      * @param desktopName The filename of the configuration file.
