@@ -1,7 +1,7 @@
 
 #include "%{APPNAMELC}_part.h"
 
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdeaction.h>
 #include <kstdaction.h>
 #include <tdefiledialog.h>
@@ -82,7 +82,7 @@ bool %{APPNAME}Part::openFile()
 {
     // m_file is always local so we can use TQFile on it
     TQFile file(m_file);
-    if (file.open(IO_ReadOnly) == false)
+    if (!file.open(IO_ReadOnly))
         return false;
 
     // our example widget is text-based, so we use TQTextStream instead
@@ -106,12 +106,12 @@ bool %{APPNAME}Part::openFile()
 bool %{APPNAME}Part::saveFile()
 {
     // if we aren't read-write, return immediately
-    if (isReadWrite() == false)
+    if (!isReadWrite())
         return false;
 
     // m_file is always local, so we use TQFile
     TQFile file(m_file);
-    if (file.open(IO_WriteOnly) == false)
+    if (!file.open(IO_WriteOnly))
         return false;
 
     // use TQTextStream to dump the text to the file
@@ -130,7 +130,7 @@ void %{APPNAME}Part::fileOpen()
     // button is clicked
     TQString file_name = KFileDialog::getOpenFileName();
 
-    if (file_name.isEmpty() == false)
+    if (!file_name.isEmpty())
         openURL(file_name);
 }
 
@@ -138,7 +138,7 @@ void %{APPNAME}Part::fileSaveAs()
 {
     // this slot is called whenever the File->Save As menu is selected,
     TQString file_name = KFileDialog::getSaveFileName();
-    if (file_name.isEmpty() == false)
+    if (!file_name.isEmpty())
         saveAs(file_name);
 }
 
