@@ -39,7 +39,7 @@
  * You might also want to reimplement mouse*Event to use some simple actions
  */
 class  %{APPNAME} : public TQWidget {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
      %{APPNAME}(TQWidget *parent);
