@@ -64,15 +64,15 @@ CCConfigWidget::CCConfigWidget( CppSupportPart* part, TQWidget* parent, const ch
 		: CCConfigWidgetBase( parent, name )
 {
 	m_pPart = part;
-	connect( m_pPart->codeRepository(), TQT_SIGNAL( catalogRegistered( Catalog* ) ),
-	         this, TQT_SLOT( catalogRegistered( Catalog* ) ) );
-	connect( m_pPart->codeRepository(), TQT_SIGNAL( catalogUnregistered( Catalog* ) ),
-	         this, TQT_SLOT( catalogUnregistered( Catalog* ) ) );
+	connect( m_pPart->codeRepository(), TQ_SIGNAL( catalogRegistered( Catalog* ) ),
+	         this, TQ_SLOT( catalogRegistered( Catalog* ) ) );
+	connect( m_pPart->codeRepository(), TQ_SIGNAL( catalogUnregistered( Catalog* ) ),
+	         this, TQ_SLOT( catalogUnregistered( Catalog* ) ) );
 
-	connect( m_qtDir, TQT_SIGNAL(urlSelected(const TQString &)),
-		 this, TQT_SLOT(isValidTQtDir(const TQString &)));
-	connect( m_qtDir, TQT_SIGNAL(textChanged(const TQString &)),
-		 this, TQT_SLOT(isValidTQtDir(const TQString &)));
+	connect( m_qtDir, TQ_SIGNAL(urlSelected(const TQString &)),
+		 this, TQ_SLOT(isValidTQtDir(const TQString &)));
+	connect( m_qtDir, TQ_SIGNAL(textChanged(const TQString &)),
+		 this, TQ_SLOT(isValidTQtDir(const TQString &)));
 
 	initGeneralTab( );
 	initTQtTab();
@@ -401,39 +401,15 @@ void CCConfigWidget::initTQtTab()
 	c->init();
 
 	m_qtUsed->setChecked( c->isUsed() );
-	if( c->version() == 4 )
-	{
-		m_versionQt4->setChecked( true );
-		m_kdevembedded->setEnabled( false );
-		m_kdevexternal->setEnabled( false );
-		m_qtStyleVersion4->setEnabled( true );
-        m_designerPath->setEnabled( true );
-        m_qmakePath->setEnabled( true );
-        m_qtDir->setEnabled( false );
-        m_txtQtDir->setEnabled( false );
-        m_txtDesigner->setEnabled( true );
-        pluginPaths->setEnabled( true );
-	}
-	else
-	{
-		m_versionQt3->setChecked( true );
-		m_kdevembedded->setEnabled( true );
-		m_kdevexternal->setEnabled( true );
-		m_qtStyleVersion4->setEnabled( false );
-        m_designerPath->setEnabled( true );
-        m_qmakePath->setEnabled( true );
-        m_qtDir->setEnabled( true );
-        m_txtQtDir->setEnabled( true );
-        m_txtDesigner->setEnabled( true );
-        pluginPaths->setEnabled( false );
-	}
-	if( c->includeStyle() == 4 )
-	{
-		m_qtStyleVersion4->setChecked( true );
-	}else
-	{
-		m_qtStyleVersion3->setChecked( true );
-	}
+	m_versionQt3->setChecked( true );
+	m_kdevembedded->setEnabled( true );
+	m_kdevexternal->setEnabled( true );
+	m_designerPath->setEnabled( true );
+	m_qmakePath->setEnabled( true );
+	m_qtDir->setEnabled( true );
+	m_txtQtDir->setEnabled( true );
+	m_txtDesigner->setEnabled( true );
+	m_qtStyleVersion3->setChecked( true );
 	m_qtDir->setURL( c->root() );
 	isValidTQtDir(m_qtDir->url());
     m_qmakePath->setURL( c->qmakePath() );
@@ -487,21 +463,8 @@ void CCConfigWidget::saveTQtTab()
 	QtBuildConfig* c = m_pPart->qtBuildConfig();
 
 	c->setUsed( m_qtUsed->isChecked() );
-	if( m_versionQt4->isChecked() )
-	{
-		c->setVersion( 4 );
-	}
-	else
-	{
-		c->setVersion( 3 );
-	}
-	if( m_qtStyleVersion4->isChecked() )
-	{
-		c->setIncludeStyle( 4 );
-	}else
-	{
-		c->setIncludeStyle( 3 );
-	}
+	c->setVersion( 3 );
+	c->setIncludeStyle( 3 );
 	c->setRoot( m_qtDir->url() );
     c->setTQMakePath( m_qmakePath->url() );
     c->setDesignerPath( m_designerPath->url() );
@@ -524,32 +487,16 @@ void CCConfigWidget::isValidTQtDir( const TQString &dir )
 	TQFileInfo inc( dir + TQString( TQChar( TQDir::separator() ) )+
 			"include"+TQString( TQChar( TQDir::separator() ) )+
 			"tqt.h" );
-	if ( !m_versionQt4->isChecked() && !inc.exists() )
-	{
-		m_qtDir->lineEdit()->setPaletteForegroundColor(TQColor("#ff0000"));
-	}else
-	{
-		m_qtDir->lineEdit()->unsetPalette();
-	}
+	m_qtDir->lineEdit()->unsetPalette();
 }
 
 void CCConfigWidget::toggleTQtVersion( bool )
 {
   if ( m_versionQt3->isChecked() )
   {
-    m_qtStyleVersion4->setEnabled( false );
     m_qtStyleVersion3->setChecked( true );
     m_kdevembedded->setEnabled( true );
     m_kdevexternal->setEnabled( true );
-    pluginPaths->setEnabled( false );
-  }
-  if ( m_versionQt4->isChecked() )
-  {
-    m_qtStyleVersion4->setEnabled( true );
-    m_tqtdesigner->setChecked( true );
-    m_kdevembedded->setEnabled( false );
-    m_kdevexternal->setEnabled( false );
-    pluginPaths->setEnabled( true );
   }
   isValidTQtDir( m_qtDir->url() );
   isTQMakeExecutable( m_qmakePath->url() );
@@ -563,15 +510,15 @@ void CCConfigWidget::openPluginPaths()
     KDialog d( this );
     TQVBoxLayout* mainlayout = new TQVBoxLayout( &d );
     KPushButton* ok = new KPushButton( KStdGuiItem::ok(), &d );
-    connect( ok, TQT_SIGNAL(clicked()), &d, TQT_SLOT(accept()));
+    connect( ok, TQ_SIGNAL(clicked()), &d, TQ_SLOT(accept()));
     KPushButton* cancel = new KPushButton( KStdGuiItem::cancel(), &d );
-    connect( cancel, TQT_SIGNAL(clicked()), &d, TQT_SLOT(reject()));
+    connect( cancel, TQ_SIGNAL(clicked()), &d, TQ_SLOT(reject()));
     TQHBoxLayout* btns = new TQHBoxLayout( &d );
     btns->addItem( new TQSpacerItem(10,10,TQSizePolicy::Expanding) );
     btns->addWidget(ok);
     btns->addWidget(cancel);
 
-    d.setCaption( i18n( "Edit TQt4 Designer Plugin Paths" ) );
+    d.setCaption( i18n( "Edit TQt Designer Plugin Paths" ) );
     KURLRequester * req = new KURLRequester( &d );
     req->setMode( KFile::Directory );
     KEditListBox* p = new KEditListBox( i18n( "Plugin Paths" ), req->customEditor(), &d );
