@@ -9,17 +9,17 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <kstandarddirs.h>
 #include <kdevplugininfo.h>
 #include "cppsupportfactory.h"
 
 K_EXPORT_COMPONENT_FACTORY( libkdevcppsupport, CppSupportFactory )
 
-static const KDevPluginInfo data("kdevcppsupport");
+static const KDevPluginInfo pluginData("kdevcppsupport");
 
 CppSupportFactory::CppSupportFactory()
-: KDevGenericFactory<CppSupportPart>( data )
+: KDevGenericFactory<CppSupportPart>( pluginData )
 {
 }
 
@@ -35,5 +35,5 @@ TDEInstance *CppSupportFactory::createInstance()
 
 const KDevPluginInfo * CppSupportFactory::info()
 {
-	return &data;
+	return &pluginData;
 }
