@@ -29,7 +29,7 @@
 #include <kiconloader.h>
 #include <tdelistview.h>
 #include <tdeapplication.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <kstandarddirs.h>
 #include <tdelocale.h>
 #include <kstringhandler.h>
