@@ -107,13 +107,13 @@ void DbgMoveHandle::mousePressEvent(TQMouseEvent *e)
     if (moving_)
         return;
 
-    if (e->button() == Qt::RightButton) {
+    if (e->button() == TQt::RightButton) {
         TDEPopupMenu *menu = new TDEPopupMenu(this);
 	menu->insertTitle(i18n("Debug Toolbar"));
         menu->insertItem(i18n("Dock to Panel"),
-                         parent(), TQT_SLOT(slotDock()));
+                         parent(), TQ_SLOT(slotDock()));
         menu->insertItem(i18n("Dock to Panel && Iconify TDevelop"),
-                         parent(), TQT_SLOT(slotIconifyAndDock()));
+                         parent(), TQ_SLOT(slotIconifyAndDock()));
         menu->popup(e->globalPos());
     } else {
         moving_ = true;
@@ -233,18 +233,18 @@ void DbgDocker::mousePressEvent(TQMouseEvent *e)
         return;
 
     switch (e->button()) {
-    case Qt::LeftButton:
+    case TQt::LeftButton:
         {
             // Not really a click, but it'll hold for the time being !!!
             emit clicked();
             break;
         }
-    case Qt::RightButton:
+    case TQt::RightButton:
         {
             TDEPopupMenu* menu = new TDEPopupMenu(this);
 	    menu->insertTitle(i18n("Debug Toolbar"));
-            menu->insertItem(i18n("Activate"),                        toolBar_, TQT_SLOT(slotUndock()));
-            menu->insertItem(i18n("Activate (TDevelop gets focus)"),  toolBar_, TQT_SLOT(slotActivateAndUndock()));
+            menu->insertItem(i18n("Activate"),                        toolBar_, TQ_SLOT(slotUndock()));
+            menu->insertItem(i18n("Activate (TDevelop gets focus)"),  toolBar_, TQ_SLOT(slotActivateAndUndock()));
             menu->popup(e->globalPos());
             break;
         }
@@ -270,9 +270,9 @@ DbgToolBar::DbgToolBar(DebuggerPart* part,
       docker_(0),
       dockWindow_(new KSystemTray(parent))
 {
-    winModule_  = new KWinModule(TQT_TQOBJECT(this));
+    winModule_  = new KWinModule(this);
     docker_ = new DbgDocker(parent, this, BarIcon("dbgnext"));
-    connect(docker_, TQT_SIGNAL(clicked()), part_, TQT_SLOT(slotStepOver()));
+    connect(docker_, TQ_SIGNAL(clicked()), part_, TQ_SLOT(slotStepOver()));
 
     // Must have noFocus set so that we can see what window was active.
     // see slotDbgKdevFocus() for more comments
@@ -310,17 +310,17 @@ DbgToolBar::DbgToolBar(DebuggerPart* part,
     bKDevFocus_ = new DbgButton(BarIcon("tdevelop"),      TQString(),      this);
     bPrevFocus_ = new DbgButton(BarIcon("dbgmemview"),    TQString(),      this);
 
-  connect(bRun,        TQT_SIGNAL(clicked()), part_,  TQT_SLOT(slotRun()));
-  connect(bInterrupt,  TQT_SIGNAL(clicked()), part_,  TQT_SLOT(slotPause()));
-  connect(bNext,       TQT_SIGNAL(clicked()), part_,  TQT_SLOT(slotStepOver()));
-  connect(bNexti,      TQT_SIGNAL(clicked()), part_,  TQT_SLOT(slotStepOverInstruction()));
-  connect(bStep,       TQT_SIGNAL(clicked()), part_,  TQT_SLOT(slotStepInto()));
-  connect(bStepi,      TQT_SIGNAL(clicked()), part_,  TQT_SLOT(slotStepIntoInstruction()));
-  connect(bFinish,     TQT_SIGNAL(clicked()), part_,  TQT_SLOT(slotStepOut()));
-  connect(bRunTo,      TQT_SIGNAL(clicked()), part_,  TQT_SLOT(slotRunToCursor()));
-  connect(bView,       TQT_SIGNAL(clicked()), part_,  TQT_SLOT(slotMemoryView()));
-  connect(bKDevFocus_, TQT_SIGNAL(clicked()), this,   TQT_SLOT(slotKdevFocus()));
-  connect(bPrevFocus_, TQT_SIGNAL(clicked()), this,   TQT_SLOT(slotPrevFocus()));
+  connect(bRun,        TQ_SIGNAL(clicked()), part_,  TQ_SLOT(slotRun()));
+  connect(bInterrupt,  TQ_SIGNAL(clicked()), part_,  TQ_SLOT(slotPause()));
+  connect(bNext,       TQ_SIGNAL(clicked()), part_,  TQ_SLOT(slotStepOver()));
+  connect(bNexti,      TQ_SIGNAL(clicked()), part_,  TQ_SLOT(slotStepOverInstruction()));
+  connect(bStep,       TQ_SIGNAL(clicked()), part_,  TQ_SLOT(slotStepInto()));
+  connect(bStepi,      TQ_SIGNAL(clicked()), part_,  TQ_SLOT(slotStepIntoInstruction()));
+  connect(bFinish,     TQ_SIGNAL(clicked()), part_,  TQ_SLOT(slotStepOut()));
+  connect(bRunTo,      TQ_SIGNAL(clicked()), part_,  TQ_SLOT(slotRunToCursor()));
+  connect(bView,       TQ_SIGNAL(clicked()), part_,  TQ_SLOT(slotMemoryView()));
+  connect(bKDevFocus_, TQ_SIGNAL(clicked()), this,   TQ_SLOT(slotKdevFocus()));
+  connect(bPrevFocus_, TQ_SIGNAL(clicked()), this,   TQ_SLOT(slotPrevFocus()));
 
     TQToolTip::add( bRun,        i18n("Continue with application execution, may start the application") );
     TQToolTip::add( bInterrupt,  i18n("Interrupt the application execution") );
