@@ -25,7 +25,7 @@ class DebuggerPart;
 
 class DebuggerConfigWidget : public DebuggerConfigWidgetBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
