@@ -18,7 +18,7 @@ class SettingsDialog;
 
 class KDevCustomImporter : public KDevPCSImporter
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
     KDevCustomImporter(TQObject* parent = 0, const char* name = 0, const TQStringList &args = TQStringList());
