@@ -313,7 +313,7 @@ bool SubclassingDlg::replaceKeywords(TQString &buffer,bool canBeModal)
 	replace(buffer,"$NEWFILENAMELC$",m_edFileName->text().lower());
 	if (canBeModal)
 	{
-		replace(buffer,"$CAN_BE_MODAL_H$",", bool modal = FALSE");
+		replace(buffer,"$CAN_BE_MODAL_H$",", bool modal = false");
 		replace(buffer,"$CAN_BE_MODAL_CPP1$",", bool modal");
 		replace(buffer,"$CAN_BE_MODAL_CPP2$",", modal");
 	}
