@@ -27,7 +27,7 @@ class kjsSupportPart;
 */
 class KJSProblems : public TDEListView
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 
