@@ -22,7 +22,7 @@
 #include "phpconfigdata.h"
 
 #include <kdevcore.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <kstandarddirs.h>
 #include <kdebug.h>
 
