@@ -130,8 +130,8 @@ RDBController::RDBController(VariableTree *varTree, FramestackWidget *frameStack
 	bind(masterSocket_, (const struct sockaddr*) &sockaddr, sizeof(sockaddr));
 	listen(masterSocket_, 1);
 	acceptNotifier_ = new TQSocketNotifier(masterSocket_, TQSocketNotifier::Read, this);
-    TQObject::connect( acceptNotifier_, TQT_SIGNAL(activated(int)),
-                          this, TQT_SLOT(slotAcceptConnection(int)) );	
+    TQObject::connect( acceptNotifier_, TQ_SIGNAL(activated(int)),
+                          this, TQ_SLOT(slotAcceptConnection(int)) );	
 						  	
     configure();
     cmdList_.setAutoDelete(true);
@@ -696,8 +696,8 @@ void RDBController::slotStart(const TQString& ruby_interpreter, const TQString&
     tty_ = new STTY(config_dbgTerminal_, Settings::terminalEmulatorName( *kapp->config() ));
     if (!config_dbgTerminal_)
     {
-        connect( tty_, TQT_SIGNAL(OutOutput(const char*)), TQT_SIGNAL(ttyStdout(const char*)) );
-        connect( tty_, TQT_SIGNAL(ErrOutput(const char*)), TQT_SIGNAL(ttyStderr(const char*)) );
+        connect( tty_, TQ_SIGNAL(OutOutput(const char*)), TQ_SIGNAL(ttyStdout(const char*)) );
+        connect( tty_, TQ_SIGNAL(ErrOutput(const char*)), TQ_SIGNAL(ttyStderr(const char*)) );
     }
 
     TQString tty(tty_->getSlave());
@@ -716,17 +716,17 @@ void RDBController::slotStart(const TQString& ruby_interpreter, const TQString&
 
     dbgProcess_ = new TDEProcess;
 
-    connect( dbgProcess_, TQT_SIGNAL(receivedStdout(TDEProcess *, char *, int)),
-             this,        TQT_SLOT(slotDbgStdout(TDEProcess *, char *, int)) );
+    connect( dbgProcess_, TQ_SIGNAL(receivedStdout(TDEProcess *, char *, int)),
+             this,        TQ_SLOT(slotDbgStdout(TDEProcess *, char *, int)) );
 
-    connect( dbgProcess_, TQT_SIGNAL(receivedStderr(TDEProcess *, char *, int)),
-             this,        TQT_SLOT(slotDbgStderr(TDEProcess *, char *, int)) );
+    connect( dbgProcess_, TQ_SIGNAL(receivedStderr(TDEProcess *, char *, int)),
+             this,        TQ_SLOT(slotDbgStderr(TDEProcess *, char *, int)) );
 
-    connect( dbgProcess_, TQT_SIGNAL(wroteStdin(TDEProcess *)),
-             this,        TQT_SLOT(slotDbgWroteStdin(TDEProcess *)) );
+    connect( dbgProcess_, TQ_SIGNAL(wroteStdin(TDEProcess *)),
+             this,        TQ_SLOT(slotDbgWroteStdin(TDEProcess *)) );
 
-    connect( dbgProcess_, TQT_SIGNAL(processExited(TDEProcess*)),
-             this,        TQT_SLOT(slotDbgProcessExited(TDEProcess*)) );
+    connect( dbgProcess_, TQ_SIGNAL(processExited(TDEProcess*)),
+             this,        TQ_SLOT(slotDbgProcessExited(TDEProcess*)) );
 
 	rubyInterpreter_ = ruby_interpreter;
 	characterCoding_ = character_coding;
@@ -1199,8 +1199,8 @@ void RDBController::slotAcceptConnection(int masterSocket)
 	}
 	
 	socketNotifier_ = new TQSocketNotifier(socket_, TQSocketNotifier::Read, 0);
-    TQObject::connect( socketNotifier_, TQT_SIGNAL(activated(int)),
-                          this, TQT_SLOT(slotReadFromSocket(int)) );	
+    TQObject::connect( socketNotifier_, TQ_SIGNAL(activated(int)),
+                          this, TQ_SLOT(slotReadFromSocket(int)) );	
     
 	setStateOff(s_dbgNotStarted);
     emit dbgStatus ("", state_);
