@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "antlr/LLkParser.hpp"
+#include "antlr/LLkParser.h"
 #include <iostream>
 
 #ifdef ANTLR_CXX_SUPPORTS_NAMESPACE
