@@ -19,15 +19,6 @@
 namespace antlr {
 #endif
 
-// wh: hack for Borland C++ 5.6
-#if __BORLANDC__
-  using std::sprintf;
-#endif
-
-
-// RK: should be using snprintf actually... (or stringstream)
-ANTLR_C_USING(sprintf)
-
 ANTLR_USE_NAMESPACE(std)string operator+( const ANTLR_USE_NAMESPACE(std)string& lhs, const int rhs )
 {
 	char tmp[100];
