@@ -22,12 +22,12 @@ BlockingTDEProcess::BlockingTDEProcess(TQObject *parent, const char *name)
   m_timeoutValue = 60;
   m_timer = 0L;
   
-  connect(this, TQT_SIGNAL(receivedStdout(TDEProcess *, char *, int)),
-          this, TQT_SLOT(slotReceivedStdOut(TDEProcess *, char *, int)));
-  connect(this, TQT_SIGNAL(receivedStderr(TDEProcess *, char *, int)),
-          this, TQT_SLOT(slotReceivedStdErr(TDEProcess *, char *, int)));
-  connect(this, TQT_SIGNAL(processExited(TDEProcess *)),
-          this, TQT_SLOT(slotProcessExited(TDEProcess *)));  
+  connect(this, TQ_SIGNAL(receivedStdout(TDEProcess *, char *, int)),
+          this, TQ_SLOT(slotReceivedStdOut(TDEProcess *, char *, int)));
+  connect(this, TQ_SIGNAL(receivedStderr(TDEProcess *, char *, int)),
+          this, TQ_SLOT(slotReceivedStdErr(TDEProcess *, char *, int)));
+  connect(this, TQ_SIGNAL(processExited(TDEProcess *)),
+          this, TQ_SLOT(slotProcessExited(TDEProcess *)));  
 }
 
 BlockingTDEProcess::BlockingTDEProcess()
@@ -37,12 +37,12 @@ BlockingTDEProcess::BlockingTDEProcess()
   m_stdErr = "";
   m_timeoutValue = 60;
   m_timer = 0L;
-  connect(this, TQT_SIGNAL(receivedStdout(TDEProcess *, char *, int)),
-          this, TQT_SLOT(slotReceivedStdOut(TDEProcess *, char *, int)));
-  connect(this, TQT_SIGNAL(receivedStderr(TDEProcess *, char *, int)),
-          this, TQT_SLOT(slotReceivedStdErr(TDEProcess *, char *, int)));
-  connect(this, TQT_SIGNAL(processExited(TDEProcess *)),
-          this, TQT_SLOT(slotProcessExited(TDEProcess *)));  
+  connect(this, TQ_SIGNAL(receivedStdout(TDEProcess *, char *, int)),
+          this, TQ_SLOT(slotReceivedStdOut(TDEProcess *, char *, int)));
+  connect(this, TQ_SIGNAL(receivedStderr(TDEProcess *, char *, int)),
+          this, TQ_SLOT(slotReceivedStdErr(TDEProcess *, char *, int)));
+  connect(this, TQ_SIGNAL(processExited(TDEProcess *)),
+          this, TQ_SLOT(slotProcessExited(TDEProcess *)));  
 }
 
 
@@ -55,7 +55,7 @@ bool BlockingTDEProcess::start(RunMode runmode, Communication comm)
   {
     m_timeout = false;
     m_timer = new TQTimer();
-    connect(m_timer, TQT_SIGNAL(timeout()), this, TQT_SLOT(slotTimeOut()));
+    connect(m_timer, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotTimeOut()));
     m_timer->start(m_timeoutValue*1000, true);
     enter_loop();
     delete m_timer;
