@@ -24,54 +24,54 @@ KDevHTMLPart::KDevHTMLPart()
 {
   setXMLFile(locate("data", "tdevelop/kdevhtml_partui.rc"), true);
   
-  connect(browserExtension(), TQT_SIGNAL(openURLRequestDelayed(const KURL &,const KParts::URLArgs &)),
-          this, TQT_SLOT(openURLRequest(const KURL &)) );
+  connect(browserExtension(), TQ_SIGNAL(openURLRequestDelayed(const KURL &,const KParts::URLArgs &)),
+          this, TQ_SLOT(openURLRequest(const KURL &)) );
 
-  connect(this, TQT_SIGNAL(started(TDEIO::Job *)), this, TQT_SLOT(slotStarted(TDEIO::Job* )));
-  connect(this, TQT_SIGNAL(completed()), this, TQT_SLOT(slotCompleted()));
-  connect(this, TQT_SIGNAL(canceled(const TQString &)), this, TQT_SLOT(slotCancelled(const TQString &)));
+  connect(this, TQ_SIGNAL(started(TDEIO::Job *)), this, TQ_SLOT(slotStarted(TDEIO::Job* )));
+  connect(this, TQ_SIGNAL(completed()), this, TQ_SLOT(slotCompleted()));
+  connect(this, TQ_SIGNAL(canceled(const TQString &)), this, TQ_SLOT(slotCancelled(const TQString &)));
 
   TDEActionCollection * actions = actionCollection();// new TDEActionCollection( this );
   reloadAction = new TDEAction( i18n( "Reload" ), "reload", 0,
-    this, TQT_SLOT( slotReload() ), actions, "doc_reload" );
+    this, TQ_SLOT( slotReload() ), actions, "doc_reload" );
   reloadAction->setWhatsThis(i18n("<b>Reload</b><p>Reloads the current document."));
   stopAction = new TDEAction( i18n( "Stop" ), "process-stop", 0,
-    this, TQT_SLOT( slotStop() ), actions, "doc_stop" );
+    this, TQ_SLOT( slotStop() ), actions, "doc_stop" );
   stopAction->setWhatsThis(i18n("<b>Stop</b><p>Stops the loading of current document."));
   duplicateAction = new TDEAction( i18n( "Duplicate Tab" ), "window-new", 0,
-    this, TQT_SLOT( slotDuplicate() ), actions, "doc_dup" );
+    this, TQ_SLOT( slotDuplicate() ), actions, "doc_dup" );
   duplicateAction->setWhatsThis(i18n("<b>Duplicate window</b><p>Opens current document in a new window."));
-  printAction = KStdAction::print(this, TQT_SLOT(slotPrint()), actions, "print_doc");
-  copyAction = KStdAction::copy(this, TQT_SLOT(slotCopy()), actions, "copy_doc_selection");
+  printAction = KStdAction::print(this, TQ_SLOT(slotPrint()), actions, "print_doc");
+  copyAction = KStdAction::copy(this, TQ_SLOT(slotCopy()), actions, "copy_doc_selection");
 
-  connect( this, TQT_SIGNAL(popupMenu(const TQString &, const TQPoint &)), this, TQT_SLOT(popup(const TQString &, const TQPoint &)));
-  connect(this, TQT_SIGNAL(selectionChanged()), this, TQT_SLOT(slotSelectionChanged()));
+  connect( this, TQ_SIGNAL(popupMenu(const TQString &, const TQPoint &)), this, TQ_SLOT(popup(const TQString &, const TQPoint &)));
+  connect(this, TQ_SIGNAL(selectionChanged()), this, TQ_SLOT(slotSelectionChanged()));
 
 //BEGIN documentation history stuff  
     
   m_backAction = new TDEToolBarPopupAction(i18n("Back"), "back", 0,
-    this, TQT_SLOT(slotBack()),
+    this, TQ_SLOT(slotBack()),
     actions, "browser_back");
   m_backAction->setEnabled( false );
   m_backAction->setToolTip(i18n("Back"));
   m_backAction->setWhatsThis(i18n("<b>Back</b><p>Moves backwards one step in the <b>documentation</b> browsing history."));
 
-  connect(m_backAction->popupMenu(), TQT_SIGNAL(aboutToShow()),
-         this, TQT_SLOT(slotBackAboutToShow()));
-  connect(m_backAction->popupMenu(), TQT_SIGNAL(activated(int)),
-         this, TQT_SLOT(slotPopupActivated(int)));
+  connect(m_backAction->popupMenu(), TQ_SIGNAL(aboutToShow()),
+         this, TQ_SLOT(slotBackAboutToShow()));
+  connect(m_backAction->popupMenu(), TQ_SIGNAL(activated(int)),
+         this, TQ_SLOT(slotPopupActivated(int)));
 
   m_forwardAction = new TDEToolBarPopupAction(i18n("Forward"), "forward", 0,
-    this, TQT_SLOT(slotForward()),
+    this, TQ_SLOT(slotForward()),
     actions, "browser_forward");
   m_forwardAction->setEnabled( false );
   m_forwardAction->setToolTip(i18n("Forward"));
   m_forwardAction->setWhatsThis(i18n("<b>Forward</b><p>Moves forward one step in the <b>documentation</b> browsing history."));
 
-  connect(m_forwardAction->popupMenu(), TQT_SIGNAL(aboutToShow()),
-         this, TQT_SLOT(slotForwardAboutToShow()));
-  connect(m_forwardAction->popupMenu(), TQT_SIGNAL(activated(int)),
-         this, TQT_SLOT(slotPopupActivated(int)));
+  connect(m_forwardAction->popupMenu(), TQ_SIGNAL(aboutToShow()),
+         this, TQ_SLOT(slotForwardAboutToShow()));
+  connect(m_forwardAction->popupMenu(), TQ_SIGNAL(activated(int)),
+         this, TQ_SLOT(slotPopupActivated(int)));
   
   m_restoring = false;
   m_Current = m_history.end();
@@ -479,9 +479,9 @@ void KDevHTMLPart::slotCopy( )
     TQString text = selectedText();
     text.replace( TQChar( 0xa0 ), ' ' );
     TQClipboard *cb = TQApplication::clipboard();
-    disconnect( cb, TQT_SIGNAL( selectionChanged() ), this, TQT_SLOT( slotClearSelection() ) );
+    disconnect( cb, TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( slotClearSelection() ) );
     cb->setText(text);
-    connect( cb, TQT_SIGNAL( selectionChanged() ), this, TQT_SLOT( slotClearSelection() ) );
+    connect( cb, TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( slotClearSelection() ) );
 }
 
 void KDevHTMLPart::slotSelectionChanged( )
