@@ -98,17 +98,17 @@ AppWizardDialog::AppWizardDialog(AppWizardPart *part, TQWidget *parent, const ch
 
 	m_customOptions = 0L;
 	loadLicenses();
-    connect( this, TQT_SIGNAL( selected( const TQString & ) ), this, TQT_SLOT( pageChanged() ) );
+    connect( this, TQ_SIGNAL( selected( const TQString & ) ), this, TQ_SLOT( pageChanged() ) );
 
 	helpButton()->hide();
     templates_listview->header()->hide();
 	templates_listview->setColumnWidthMode(0, TQListView::Maximum);	//to provide horiz scrollbar.
 
 	m_templatesMenu = new TDEPopupMenu(templates_listview);
-	m_templatesMenu->insertItem(i18n("&Add to Favorites"), this, TQT_SLOT(addTemplateToFavourites()));
+	m_templatesMenu->insertItem(i18n("&Add to Favorites"), this, TQ_SLOT(addTemplateToFavourites()));
 
 	m_favouritesMenu = new TDEPopupMenu(favourites_iconview);
-	m_favouritesMenu->insertItem(i18n("&Remove Favorite"), this, TQT_SLOT(removeFavourite()));
+	m_favouritesMenu->insertItem(i18n("&Remove Favorite"), this, TQ_SLOT(removeFavourite()));
 
     m_pathIsValid=false;
     m_part = part;
@@ -304,7 +304,7 @@ AppWizardDialog::AppWizardDialog(AppWizardPart *part, TQWidget *parent, const ch
     // How about names like "__" or "123" for project name? Are they legal?
     TQRegExpValidator *appname_edit_validator;
     appname_edit_validator = new TQRegExpValidator (appname_regexp,
-                                                   TQT_TQOBJECT(appname_edit),
+                                                   appname_edit,
                                                    "AppNameValidator");
     appname_edit->setValidator(appname_edit_validator);
 
@@ -319,7 +319,7 @@ AppWizardDialog::AppWizardDialog(AppWizardPart *part, TQWidget *parent, const ch
             license_combo->setCurrentItem( idx - 1 );
     }
 
-	connect( license_combo, TQT_SIGNAL(activated(int)), this, TQT_SLOT(licenseChanged()) );
+	connect( license_combo, TQ_SIGNAL(activated(int)), this, TQ_SLOT(licenseChanged()) );
 
 	m_custom_options_layout = new TQHBoxLayout( custom_options );
 	m_custom_options_layout->setAutoAdd(true);
