@@ -23,7 +23,7 @@ class AppWizardDialog;
 
 class AppWizardPart : public KDevPlugin
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
