@@ -23,7 +23,7 @@
 #include "classviewwidget.h"
 
 #include <kiconloader.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <kurl.h>
 #include <tdeaction.h>
 #include <tdeactionclasses.h>
