@@ -87,11 +87,11 @@ DocumentationPart::DocumentationPart(TQObject *parent, const char *name, const T
     m_configProxy = new ConfigWidgetProxy(core());
 	m_configProxy->createGlobalConfigPage(i18n("Documentation"), GLOBALDOC_OPTIONS, info()->icon() );
 	m_configProxy->createProjectConfigPage(i18n("Project Documentation"), PROJECTDOC_OPTIONS, info()->icon() );
-    connect(m_configProxy, TQT_SIGNAL(insertConfigWidget(const KDialogBase*, TQWidget*, unsigned int )), this, TQT_SLOT(insertConfigWidget(const KDialogBase*, TQWidget*, unsigned int)));
-    connect(core(), TQT_SIGNAL(contextMenu(TQPopupMenu *, const Context *)),
-        this, TQT_SLOT(contextMenu(TQPopupMenu *, const Context *)));
-    connect(core(), TQT_SIGNAL(projectOpened()), this, TQT_SLOT(projectOpened()));
-    connect(core(), TQT_SIGNAL(projectClosed()), this, TQT_SLOT(projectClosed()));
+    connect(m_configProxy, TQ_SIGNAL(insertConfigWidget(const KDialogBase*, TQWidget*, unsigned int )), this, TQ_SLOT(insertConfigWidget(const KDialogBase*, TQWidget*, unsigned int)));
+    connect(core(), TQ_SIGNAL(contextMenu(TQPopupMenu *, const Context *)),
+        this, TQ_SLOT(contextMenu(TQPopupMenu *, const Context *)));
+    connect(core(), TQ_SIGNAL(projectOpened()), this, TQ_SLOT(projectOpened()));
+    connect(core(), TQ_SIGNAL(projectClosed()), this, TQ_SLOT(projectClosed()));
 
     m_widget = new DocumentationWidget(this);
     m_widget->setIcon(SmallIcon(info()->icon()));
@@ -109,7 +109,7 @@ DocumentationPart::DocumentationPart(TQObject *parent, const char *name, const T
     setupActions();
     checkLastVersion();
     
-    TQTimer::singleShot(5, this, TQT_SLOT(init()));
+    TQTimer::singleShot(5, this, TQ_SLOT(init()));
     
     new KDevDocumentationIface(this);
 }
@@ -147,7 +147,7 @@ void DocumentationPart::loadDocumentationPlugins()
         {
             kdDebug() << "    success" << endl;
             docPlugin->init(m_widget->contents());
-            connect(this, TQT_SIGNAL(indexSelected(IndexBox* )), docPlugin, TQT_SLOT(createIndex(IndexBox* )));
+            connect(this, TQ_SIGNAL(indexSelected(IndexBox* )), docPlugin, TQ_SLOT(createIndex(IndexBox* )));
             m_plugins.append(docPlugin);
         }
     }
@@ -172,13 +172,13 @@ void DocumentationPart::insertConfigWidget(const KDialogBase *dlg, TQWidget *pag
         case GLOBALDOC_OPTIONS:
         {
             DocGlobalConfigWidget *w1 = new DocGlobalConfigWidget(this, m_widget, page, "doc config widget");
-            connect(dlg, TQT_SIGNAL(okClicked()), w1, TQT_SLOT(accept()));
+            connect(dlg, TQ_SIGNAL(okClicked()), w1, TQ_SLOT(accept()));
             break;
         }
         case PROJECTDOC_OPTIONS:
         {
             DocProjectConfigWidget *w1 = new DocProjectConfigWidget(this, page, "doc project config");
-            connect(dlg, TQT_SIGNAL(okClicked()), w1, TQT_SLOT(accept()));
+            connect(dlg, TQ_SIGNAL(okClicked()), w1, TQ_SLOT(accept()));
             break;
         }
     }
@@ -199,7 +199,7 @@ bool DocumentationPart::configure(int page)
     DocGlobalConfigWidget *w1 = new DocGlobalConfigWidget(this, m_widget, dlg.plainPage());
     l->addWidget(w1);
     w1->docTab->setCurrentPage(page);
-    connect(&dlg, TQT_SIGNAL(okClicked()), w1, TQT_SLOT(accept()));
+    connect(&dlg, TQ_SIGNAL(okClicked()), w1, TQ_SLOT(accept()));
     return (dlg.exec() == TQDialog::Accepted);
 }
 
@@ -211,7 +211,7 @@ void DocumentationPart::setupActions()
     TDEAction *action;
 
     action = new TDEAction(i18n("&Search in Documentation..."), CTRL+ALT+Key_S,
-                         this, TQT_SLOT(searchInDocumentation()),
+                         this, TQ_SLOT(searchInDocumentation()),
                          actionCollection(), "help_search_in_doc" );
     action->setToolTip(i18n("Full text search in the documentation"));
     action->setWhatsThis(i18n("<b>Search in documentation</b><p>"
@@ -222,7 +222,7 @@ void DocumentationPart::setupActions()
                               "configuration dialog of the documentation plugin."));    
 
     action = new TDEAction(i18n("&Look in Documentation Index..."), CTRL+ALT+Key_I,
-                         this, TQT_SLOT(lookInDocumentationIndex()),
+                         this, TQ_SLOT(lookInDocumentationIndex()),
                          actionCollection(), "help_look_in_index" );
     action->setToolTip(i18n("Look in the documentation index"));
     action->setWhatsThis(i18n("<b>Look in documentation index</b><p>"
@@ -231,19 +231,19 @@ void DocumentationPart::setupActions()
                               "the documentation index."));    
 
     action = new TDEAction(i18n("Man Page..."), 0,
-                         this, TQT_SLOT(manPage()),
+                         this, TQ_SLOT(manPage()),
                          actionCollection(), "help_manpage" );
     action->setToolTip(i18n("Show a manpage"));
     action->setWhatsThis(i18n("<b>Show a manpage</b><p>Opens a man page using embedded viewer."));
 
     action = new TDEAction(i18n("Info Page..."), 0,
-                         this, TQT_SLOT(infoPage()),
+                         this, TQ_SLOT(infoPage()),
                          actionCollection(), "help_infopage");
     action->setToolTip(i18n("Show an infopage"));
     action->setWhatsThis(i18n("<b>Show an infopage</b><p>Opens an info page using embedded viewer."));
 
     action = new TDEAction(i18n("Find Documentation..."), 0,
-                         this, TQT_SLOT(findInDocumentation()),
+                         this, TQ_SLOT(findInDocumentation()),
                          actionCollection(), "help_find_documentation");
     action->setToolTip(i18n("Find Documentation"));
     action->setWhatsThis(i18n("<b>Find documentation</b><p>"
@@ -467,7 +467,7 @@ void DocumentationPart::contextMenu(TQPopupMenu *popup, const Context *context)
             int id = -1;
             if (hasContextFeature(Finder)) {
                 id = popup->insertItem(i18n("Find Documentation: %1").arg(squeezed),
-                                    this, TQT_SLOT(contextFindDocumentation()));
+                                    this, TQ_SLOT(contextFindDocumentation()));
                 popup->setWhatsThis(id, i18n("<b>Find documentation</b><p>"
                                     "Opens the documentation finder tab and searches "
                                     "all possible sources of documentation like "
@@ -476,7 +476,7 @@ void DocumentationPart::contextMenu(TQPopupMenu *popup, const Context *context)
             }
             if (hasContextFeature(IndexLookup)) {
                 id = popup->insertItem(i18n("Look in Documentation Index: %1").arg(squeezed),
-                                this, TQT_SLOT(contextLookInDocumentationIndex()));
+                                this, TQ_SLOT(contextLookInDocumentationIndex()));
                 popup->setWhatsThis(id, i18n("<b>Look in documentation index</b><p>"
                                 "Opens the documentation index tab. It allows "
                                 "a term to be entered which will be looked for in "
@@ -484,7 +484,7 @@ void DocumentationPart::contextMenu(TQPopupMenu *popup, const Context *context)
             }
             if (hasContextFeature(FullTextSearch)) {
                 id = popup->insertItem(i18n("Search in Documentation: %1").arg(squeezed),
-                                this, TQT_SLOT(contextSearchInDocumentation()));
+                                this, TQ_SLOT(contextSearchInDocumentation()));
                 popup->setWhatsThis(id, i18n("<b>Search in documentation</b><p>Searches "
                                 "for a term under the cursor in "
                                 "the documentation. For this to work, "
@@ -493,12 +493,12 @@ void DocumentationPart::contextMenu(TQPopupMenu *popup, const Context *context)
             }
             if (hasContextFeature(GotoMan)) {
                 id = popup->insertItem(i18n("Goto Manpage: %1").arg(squeezed),
-                                this, TQT_SLOT(contextManPage()));
+                                this, TQ_SLOT(contextManPage()));
                 popup->setWhatsThis(id, i18n("<b>Goto manpage</b><p>Tries to open a man page for the term under the cursor."));
             }
             if (hasContextFeature(GotoInfo)) {
                 id = popup->insertItem( i18n("Goto Infopage: %1").arg(squeezed),
-                                this, TQT_SLOT(contextInfoPage()) );
+                                this, TQ_SLOT(contextInfoPage()) );
                 popup->setWhatsThis(id, i18n("<b>Goto infopage</b><p>Tries to open an info page for the term under the cursor."));
             }
             if (id != -1)
