@@ -168,7 +168,7 @@ IndexItem::List IndexItem::urls() const
     TQValueList<IndexItemProto*> itemProtos = m_listbox->items[text()];
     for (TQValueList<IndexItemProto*>::const_iterator it = itemProtos.begin();
         it != itemProtos.end(); ++it)
-        urlList.append(tqMakePair((*it)->description(), (*it)->url()));
+        urlList.append(qMakePair((*it)->description(), (*it)->url()));
     return urlList;
 }
 
@@ -224,7 +224,7 @@ void ConfigurationItem::paintCell(TQPainter *p, const TQColorGroup &cg, int colu
             y = (fm.height() + 2 + marg - boxsize) / 2;
 
         TQStyleOption opt(this);
-        lv->style().tqdrawPrimitive(TQStyle::PE_CheckListIndicator, p,
+        lv->style().drawPrimitive(TQStyle::PE_CheckListIndicator, p,
             TQRect(x, y, boxsize, fm.height() + 2 + marg), cg, styleflags, opt);
                
         return;
@@ -685,7 +685,7 @@ ProjectDocumentationPlugin::ProjectDocumentationPlugin(DocumentationPlugin *docP
     kdDebug() << "ProjectDocumentationPlugin::ProjectDocumentationPlugin for type " << type << endl;
     
     m_watch = new KDirWatch(this);
-    connect(m_watch, TQT_SIGNAL(dirty(const TQString&)), this, TQT_SLOT(reinit()));
+    connect(m_watch, TQ_SIGNAL(dirty(const TQString&)), this, TQ_SLOT(reinit()));
     m_watch->startScan();
 }
 
