@@ -22,5 +22,5 @@
 
 void FCTypeEditBase::init()
 {
-    typeext_edit->setValidator(new TQRegExpValidator(TQRegExp("^\\S*$"), TQT_TQOBJECT(this)));
+    typeext_edit->setValidator(new TQRegExpValidator(TQRegExp("^\\S*$"), this));
 }
