@@ -125,7 +125,7 @@ KDevFileSelector::KDevFileSelector( FileSelectorPart *part, KDevMainWindow *main
 
     TQVBoxLayout* lo = new TQVBoxLayout(this);
 
-    TQtMsgHandler oldHandler = tqInstallMsgHandler( silenceTQToolBar );
+    TQtMsgHandler oldHandler = qInstallMsgHandler( silenceTQToolBar );
 
     KDevFileSelectorToolBarParent *tbp=new KDevFileSelectorToolBarParent(this);
     toolbar = new KDevFileSelectorToolBar(tbp);
@@ -133,7 +133,7 @@ KDevFileSelector::KDevFileSelector( FileSelectorPart *part, KDevMainWindow *main
     lo->addWidget(tbp);
     toolbar->setMovingEnabled(false);
     toolbar->setFlat(true);
-    tqInstallMsgHandler( oldHandler );
+    qInstallMsgHandler( oldHandler );
 
     cmbPath = new KURLComboBox( KURLComboBox::Directories, true, this, "path combo" );
     cmbPath->setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Fixed ));
@@ -173,41 +173,41 @@ KDevFileSelector::KDevFileSelector( FileSelectorPart *part, KDevMainWindow *main
     filter = new KHistoryCombo( true, filterBox, "filter");
     filter->setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Fixed ));
     filterBox->setStretchFactor(filter, 2);
-    connect( btnFilter, TQT_SIGNAL( clicked() ), this, TQT_SLOT( btnFilterClick() ) );
+    connect( btnFilter, TQ_SIGNAL( clicked() ), this, TQ_SLOT( btnFilterClick() ) );
     lo->addWidget(filterBox);
 
-    connect( filter, TQT_SIGNAL( activated(const TQString&) ),
-             TQT_SLOT( slotFilterChange(const TQString&) ) );
+    connect( filter, TQ_SIGNAL( activated(const TQString&) ),
+             TQ_SLOT( slotFilterChange(const TQString&) ) );
 
-    connect( filter, TQT_SIGNAL( textChanged(const TQString&) ),
-             TQT_SLOT( slotFilterChange(const TQString&) ) );
-    connect( filter, TQT_SIGNAL( returnPressed(const TQString&) ),
-             filter, TQT_SLOT( addToHistory(const TQString&) ) );
+    connect( filter, TQ_SIGNAL( textChanged(const TQString&) ),
+             TQ_SLOT( slotFilterChange(const TQString&) ) );
+    connect( filter, TQ_SIGNAL( returnPressed(const TQString&) ),
+             filter, TQ_SLOT( addToHistory(const TQString&) ) );
 
     // tdeaction for the dir sync method
     acSyncDir = new TDEAction( i18n("Current Document Directory"), "dirsynch", 0,
-                             TQT_TQOBJECT(this), TQT_SLOT( setActiveDocumentDir() ), mActionCollection, "sync_dir" );
+                             this, TQ_SLOT( setActiveDocumentDir() ), mActionCollection, "sync_dir" );
     toolbar->setIconText( TDEToolBar::IconOnly );
     toolbar->setIconSize( 16 );
     toolbar->setEnableContextMenu( false );
 
-    connect( cmbPath, TQT_SIGNAL( urlActivated( const KURL&  )),
-             this,  TQT_SLOT( cmbPathActivated( const KURL& ) ));
-    connect( cmbPath, TQT_SIGNAL( returnPressed( const TQString&  )),
-             this,  TQT_SLOT( cmbPathReturnPressed( const TQString& ) ));
-    connect(dir, TQT_SIGNAL(urlEntered(const KURL&)),
-            this, TQT_SLOT(dirUrlEntered(const KURL&)) );
+    connect( cmbPath, TQ_SIGNAL( urlActivated( const KURL&  )),
+             this,  TQ_SLOT( cmbPathActivated( const KURL& ) ));
+    connect( cmbPath, TQ_SIGNAL( returnPressed( const TQString&  )),
+             this,  TQ_SLOT( cmbPathReturnPressed( const TQString& ) ));
+    connect(dir, TQ_SIGNAL(urlEntered(const KURL&)),
+            this, TQ_SLOT(dirUrlEntered(const KURL&)) );
 
-    connect(dir, TQT_SIGNAL(finishedLoading()),
-            this, TQT_SLOT(dirFinishedLoading()) );
+    connect(dir, TQ_SIGNAL(finishedLoading()),
+            this, TQ_SLOT(dirFinishedLoading()) );
 
     // enable dir sync button if current doc has a valid URL
-    connect ( partController, TQT_SIGNAL(activePartChanged(KParts::Part*) ),
-              this, TQT_SLOT(viewChanged() ) );
+    connect ( partController, TQ_SIGNAL(activePartChanged(KParts::Part*) ),
+              this, TQ_SLOT(viewChanged() ) );
 
     // Connect the bookmark handler
-    connect( bookmarkHandler, TQT_SIGNAL( openURL( const TQString& )),
-             this, TQT_SLOT( setDir( const TQString& ) ) );
+    connect( bookmarkHandler, TQ_SIGNAL( openURL( const TQString& )),
+             this, TQ_SLOT( setDir( const TQString& ) ) );
 
     waitingUrl = TQString();
 
@@ -256,7 +256,7 @@ void KDevFileSelector::readConfig(TDEConfig *config, const TQString & name)
         if ( ! loc.isEmpty() )
         {
             waitingDir = loc;
-            TQTimer::singleShot(0, this, TQT_SLOT(initialDirChangeHack()));
+            TQTimer::singleShot(0, this, TQ_SLOT(initialDirChangeHack()));
         }
     }
 
@@ -275,11 +275,11 @@ void KDevFileSelector::readConfig(TDEConfig *config, const TQString & name)
     // connect events as needed
     /// @todo - solve startup problem: no need to set location for each doc opened!
     if ( autoSyncEvents & DocumentChanged )
-        connect( partController, TQT_SIGNAL( viewChanged() ), this, TQT_SLOT( autoSync() ) );
+        connect( partController, TQ_SIGNAL( viewChanged() ), this, TQ_SLOT( autoSync() ) );
 
     if ( autoSyncEvents & DocumentOpened )
-        connect( partController, TQT_SIGNAL( partAdded(KParts::Part*) ),
-                 this, TQT_SLOT( autoSync(KParts::Part*) ) );
+        connect( partController, TQ_SIGNAL( partAdded(KParts::Part*) ),
+                 this, TQ_SLOT( autoSync(KParts::Part*) ) );
 
 }
 
@@ -585,25 +585,25 @@ KFSConfigPage::KFSConfigPage( TQWidget *parent, const char *name, KDevFileSelect
     lo->setSpacing( spacing );
 
     // Toolbar - a lot for a little...
-    TQGroupBox *gbToolbar = new TQGroupBox( 1, Qt::Vertical, i18n("Toolbar"), this );
+    TQGroupBox *gbToolbar = new TQGroupBox( 1, TQt::Vertical, i18n("Toolbar"), this );
     acSel = new TDEActionSelector( gbToolbar );
     acSel->setAvailableLabel( i18n("A&vailable actions:") );
     acSel->setSelectedLabel( i18n("S&elected actions:") );
     lo->addWidget( gbToolbar );
-    connect( acSel, TQT_SIGNAL( added( TQListBoxItem * ) ), this, TQT_SLOT( slotChanged() ) );
-    connect( acSel, TQT_SIGNAL( removed( TQListBoxItem * ) ), this, TQT_SLOT( slotChanged() ) );
-    connect( acSel, TQT_SIGNAL( movedUp( TQListBoxItem * ) ), this, TQT_SLOT( slotChanged() ) );
-    connect( acSel, TQT_SIGNAL( movedDown( TQListBoxItem * ) ), this, TQT_SLOT( slotChanged() ) );
+    connect( acSel, TQ_SIGNAL( added( TQListBoxItem * ) ), this, TQ_SLOT( slotChanged() ) );
+    connect( acSel, TQ_SIGNAL( removed( TQListBoxItem * ) ), this, TQ_SLOT( slotChanged() ) );
+    connect( acSel, TQ_SIGNAL( movedUp( TQListBoxItem * ) ), this, TQ_SLOT( slotChanged() ) );
+    connect( acSel, TQ_SIGNAL( movedDown( TQListBoxItem * ) ), this, TQ_SLOT( slotChanged() ) );
 
     // Sync
-    TQGroupBox *gbSync = new TQGroupBox( 1, Qt::Horizontal, i18n("Auto Synchronization"), this );
+    TQGroupBox *gbSync = new TQGroupBox( 1, TQt::Horizontal, i18n("Auto Synchronization"), this );
     cbSyncActive = new TQCheckBox( i18n("When a docu&ment becomes active"), gbSync );
     cbSyncOpen = new TQCheckBox( i18n("When a document is o&pened"), gbSync );
     cbSyncShow = new TQCheckBox( i18n("When the file selector becomes visible"), gbSync );
     lo->addWidget( gbSync );
-    connect( cbSyncActive, TQT_SIGNAL( toggled( bool ) ), this, TQT_SLOT( slotChanged() ) );
-    connect( cbSyncOpen, TQT_SIGNAL( toggled( bool ) ), this, TQT_SLOT( slotChanged() ) );
-    connect( cbSyncShow, TQT_SIGNAL( toggled( bool ) ), this, TQT_SLOT( slotChanged() ) );
+    connect( cbSyncActive, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( slotChanged() ) );
+    connect( cbSyncOpen, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( slotChanged() ) );
+    connect( cbSyncShow, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( slotChanged() ) );
 
     // Histories
     TQHBox *hbPathHist = new TQHBox ( this );
@@ -611,22 +611,22 @@ KFSConfigPage::KFSConfigPage( TQWidget *parent, const char *name, KDevFileSelect
     sbPathHistLength = new TQSpinBox( hbPathHist );
     lbPathHist->setBuddy( sbPathHistLength );
     lo->addWidget( hbPathHist );
-    connect( sbPathHistLength, TQT_SIGNAL( valueChanged ( int ) ), this, TQT_SLOT( slotChanged() ) );
+    connect( sbPathHistLength, TQ_SIGNAL( valueChanged ( int ) ), this, TQ_SLOT( slotChanged() ) );
 
     TQHBox *hbFilterHist = new TQHBox ( this );
     TQLabel *lbFilterHist = new TQLabel( i18n("Remember &filters:"), hbFilterHist );
     sbFilterHistLength = new TQSpinBox( hbFilterHist );
     lbFilterHist->setBuddy( sbFilterHistLength );
     lo->addWidget( hbFilterHist );
-    connect( sbFilterHistLength, TQT_SIGNAL( valueChanged ( int ) ), this, TQT_SLOT( slotChanged() ) );
+    connect( sbFilterHistLength, TQ_SIGNAL( valueChanged ( int ) ), this, TQ_SLOT( slotChanged() ) );
 
     // Session
-    TQGroupBox *gbSession = new TQGroupBox( 1, Qt::Horizontal, i18n("Session"), this );
+    TQGroupBox *gbSession = new TQGroupBox( 1, TQt::Horizontal, i18n("Session"), this );
     cbSesLocation = new TQCheckBox( i18n("Restore loca&tion"), gbSession );
     cbSesFilter = new TQCheckBox( i18n("Restore last f&ilter"), gbSession );
     lo->addWidget( gbSession );
-    connect( cbSesLocation, TQT_SIGNAL( toggled( bool ) ), this, TQT_SLOT( slotChanged() ) );
-    connect( cbSesFilter, TQT_SIGNAL( toggled( bool ) ), this, TQT_SLOT( slotChanged() ) );
+    connect( cbSesLocation, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( slotChanged() ) );
+    connect( cbSesFilter, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( slotChanged() ) );
 
     // make it look nice
     lo->addStretch( 1 );
@@ -713,16 +713,16 @@ void KFSConfigPage::apply()
         s |= KDevFileSelector::GotVisible;
     fileSelector->autoSyncEvents = s;
     // reset connections
-    disconnect( fileSelector->partController, 0, fileSelector, TQT_SLOT( autoSync() ) );
+    disconnect( fileSelector->partController, 0, fileSelector, TQ_SLOT( autoSync() ) );
     disconnect( fileSelector->partController, 0,
-                fileSelector, TQT_SLOT( autoSync( KParts::Part *) ) );
+                fileSelector, TQ_SLOT( autoSync( KParts::Part *) ) );
     if ( s & KDevFileSelector::DocumentChanged )
-        connect( fileSelector->partController, TQT_SIGNAL( viewChanged() ),
-                 fileSelector, TQT_SLOT( autoSync() ) );
+        connect( fileSelector->partController, TQ_SIGNAL( viewChanged() ),
+                 fileSelector, TQ_SLOT( autoSync() ) );
     if ( s & KDevFileSelector::DocumentOpened )
         connect( fileSelector->partController,
-                 TQT_SIGNAL( partAdded(KParts::Part *) ),
-                 fileSelector, TQT_SLOT( autoSync(KParts::Part *) ) );
+                 TQ_SIGNAL( partAdded(KParts::Part *) ),
+                 fileSelector, TQ_SLOT( autoSync(KParts::Part *) ) );
 
     // histories
     fileSelector->cmbPath->setMaxItems( sbPathHistLength->value() );
