@@ -21,7 +21,7 @@ class MakeItem;
 
 class CompileErrorFilter : public TQObject, public OutputFilter
 {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
