@@ -27,11 +27,11 @@
 
 class QuickOpenFunctionChooseForm : public QuickOpenFunctionChooseFormBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
-  QuickOpenFunctionChooseForm(TQWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
+  QuickOpenFunctionChooseForm(TQWidget* parent = 0, const char* name = 0, bool modal = false, WFlags fl = 0 );
   ~QuickOpenFunctionChooseForm();
 
   void setRelativePath(int id, const TQString &path) { m_relPaths[id] = path; }
