@@ -22,7 +22,7 @@ class ToolsWidget;
 
 class ToolsPart : public KDevPlugin
   {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
