@@ -26,7 +26,7 @@ public:
 
 class ToolsConfig : public TQWidget
   {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
