@@ -10,7 +10,7 @@ Implements shell-dependent "duplicate" and "open in new window" actions of KDevH
 */
 class HTMLDocumentationPart : public KDevHTMLPart
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
