@@ -21,7 +21,7 @@
 */
 class ClearcaseFileinfoProvider : public KDevVCSFileInfoProvider
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
     ClearcaseFileinfoProvider(ClearcasePart *parent);
