@@ -11,7 +11,7 @@ class KURL;
 
 class SvnCopyDialog : public SvnCopyDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	SvnCopyDialog( const TQString &reqPath, SvnGlobal::SvnInfoHolder *holder, TQWidget *parent );
