@@ -11,8 +11,8 @@ SvnSwitchDlg::SvnSwitchDlg( const SvnGlobal::SvnInfoHolder *holder,
 	: SvnSwitchDlgBase( parent )
 	, m_info( holder )
 {
-	connect( switchOnlyRadio, TQT_SIGNAL(clicked()), this, TQT_SLOT(resetCurrentRepositoryUrlEdit()) );
-	connect( relocationRadio , TQT_SIGNAL(clicked()), this, TQT_SLOT(resetCurrentRepositoryUrlEdit()) );
+	connect( switchOnlyRadio, TQ_SIGNAL(clicked()), this, TQ_SLOT(resetCurrentRepositoryUrlEdit()) );
+	connect( relocationRadio , TQ_SIGNAL(clicked()), this, TQ_SLOT(resetCurrentRepositoryUrlEdit()) );
 	// set switch only
 	switchOnlyRadio->setChecked( true );
 	wcUrlEdit->setText( wcPath );
